#ifndef __FILES_H__
#define __FILES_H__
#include <sys/types.h>
#include <unistd.h>
#include <dirent.h>

#define EXTENSION_MAX 8
#define MAX_FILE_NAMES 3000
#define MAX_GROUP_EXT_STRING 256

#define GROUP_NAME_MAX 100
#define MAX_GROUPS 20

#define MAX_EDIT_WITH 20

#define SORT_TYPE_NAME 0
#define SORT_TYPE_EXTENSION 1
#define SORT_TYPE_SIZE_ASC 2
#define SORT_TYPE_SIZE_DESC 3
#define SORT_TYPE_TIME_ASC 4
#define SORT_TYPE_TIME_DESC 5
#define SORT_TYPE_GROUPS 6

#define SPECIAL_TYPE_NONE 0
#define SPECIAL_TYPE_BLOCK_DEV 1
#define SPECIAL_TYPE_CHAR_DEV 2
#define SPECIAL_TYPE_PIPE 3
#define SPECIAL_TYPE_SOCK 4

typedef struct
{
	char name[FILENAME_MAX];
	char ext[EXTENSION_MAX];//to sort by extension
	char windows_attributes;
	mode_t    st_mode;
	time_t    mtime;   /* time of last modification */
#ifndef WINDOWS
    uid_t     st_uid;     /* user ID of owner */
    gid_t     st_gid;     /* group ID of owner */
#endif
	unsigned long long int     st_size;    /* total size, in bytes */
	char is_dir;
	char is_exe;
	char is_hidden;
	char is_link;
	char is_broken;
	char is_special;
	char group;
	char priority;
	char selected;

}my_file;

typedef struct
{
	char name[GROUP_NAME_MAX];
	char extensions[MAX_GROUP_EXT_STRING];
	char priority;
	char r;
	char g;
	char b;
}group;

typedef struct
{
	char edit_with[128];
	char extensions[MAX_GROUP_EXT_STRING];
}edit_with;

extern edit_with edit_with_list[MAX_EDIT_WITH];
extern char default_editor[256];
extern char default_viewer[256];
extern char hex_viewer[256];

extern group groups[MAX_GROUPS];

int read_cur_dir(char *cur_dir, my_file *files_list, int *files_order);
void do_files_grouping(my_file *files_list, int *files_order, int files_no);
void sort_cur_dir(my_file *files_list, int *files_order, int files_no, char sort_type);

#endif

