#ifndef __GLOBAL_H__
#define __GLOBAL_H__
#include <SDL/SDL.h>
#include <SDL/SDL_endian.h>	/* Used for the endian-dependent 24 bpp mode */
#include <SDL/SDL_video.h>
#include <SDL/SDL_ttf.h>
#include <SDL/SDL_thread.h>
#include <sys/stat.h>

#ifdef WINDOWS
#include <windows.h>
#include <winbase.h>
#include <shlobj.h>
#include <sys/utime.h>
#else
#include <sys/statvfs.h>
#include <sys/types.h>
#include <utime.h>
#include <pwd.h>
#include <grp.h>
#endif

#ifndef MAX_PATH
#define MAX_PATH PATH_MAX
#endif

#include "events.h"
#include "files.h"
#include "menu_handling.h"
#include "menus.h"
#include "misc.h"
#include "text.h"
#include "panels.h"
#include "file_operations.h"
#include "gui.h"
#include "init.h"

//colors
#define C_BLACK 255
#define C_WHITE 254
#define C_ORANGE 253
#define C_RED 252
#define C_GREEN 251
#define C_DARK_RED 250
#define C_LIGHT_BLUE 249
#define C_BEIGE 248
#define C_PURPLE 247
#define C_LIGHT_YELLOW 246
#define C_DARK_BLUE 245
#define C_DARK_GRAY 244
#define C_LIGHT_GRAY 243
#define C_CURSOR_COLOR 242
#define C_SELECTED_FILE_COLOR 241
#define C_MENU_COLOR 240
#define C_MEDIUM_GRAY 239
#define C_MENU_TITLE 238

extern int window_width;
extern int window_height;


extern SDL_Color colors[256];
extern SDL_Surface *screen;
void cls(SDL_Surface * this_screen);

//events
extern int x_mouse_pos, y_mouse_pos;
extern Sint32 mouse_delta_x, mouse_delta_y;
extern int button_l;
extern int button_r;
extern int long_pressed_button_l;
extern int long_pressed_button_r;
extern int caps_lock_on;
extern int ctrl_on;
extern int shift_on;
extern int alt_on;

extern char * window_text;

extern char config_path[256];

extern int update_screen;



extern int x_font_bmp, font_height, font_colors_no;
extern int char_lenght;		//the width, in pixels, of a char

extern char show_hidden;
extern char collums_per_panel;
extern char kb_size;
extern char decimal_separator;
extern char date_format;

typedef struct
{
	char left_path[MAX_PATH];
	char right_path[MAX_PATH];
	int left_sort_type;
	int right_sort_type;
	int window_x_size;
	int window_y_size;
	bookmark bookmarks[MAX_BOOKMARKS];
	int last_bookmark;
	char show_hidden;
	char collums_per_panel;
	char date_format;
	char kb_size;
	char decimal_separator;
	char default_editor[256];
	char default_viewer[256];
	char hex_viewer[256];
	char reserved[20000];
}config;


extern config last_config;

typedef struct {
	int address;
	Uint8 type;
	char name[64];
}label;

#endif


