#include "global.h"
#include <time.h>

int
#ifdef WINDOWS
Main(int argc, char *argv[])
#else
main(int argc, char *argv[])
#endif
{
	int seed;

	load_settings();

	SDL_Init (SDL_INIT_VIDEO || SDL_INIT_TIMER);
	screen = SDL_SetVideoMode (window_width, window_height, 8,SDL_HWSURFACE | SDL_RESIZABLE | SDL_HWPALETTE);
	SDL_WM_SetIcon(SDL_LoadBMP("icon.bmp"), NULL);
	SDL_WM_SetCaption ("File Manager", "File Manager");
	if(screen == NULL)
		{
		  fprintf(stderr, "Could not initialize video\n");
		  exit(1);
		}

	if(fonts_init()==-1)exit(2);

	SDL_EnableKeyRepeat (150, 50);
#ifdef WINDOWS
	SetErrorMode(SEM_FAILCRITICALERRORS);
#endif
	//now, define our custom colors
	//black
	colors[255].r = 0;
	colors[255].g = 0;
	colors[255].b = 0;
	//white
	colors[254].r = 255;
	colors[254].g = 255;
	colors[254].b = 255;
	//orange
	colors[253].r = 215;
	colors[253].g = 123;
	colors[253].b = 0;
	//red
	colors[252].r = 255;
	colors[252].g = 50;
	colors[252].b = 50;
	//green
	colors[251].r = 20;
	colors[251].g = 250;
	colors[251].b = 40;
	//dark red
	colors[250].r = 160;
	colors[250].g = 20;
	colors[250].b = 0;
	//light blue
	colors[249].r = 20;
	colors[249].g = 130;
	colors[249].b = 250;
	//beige
	colors[248].r = 245;
	colors[248].g = 240;
	colors[248].b = 210;
	//purple
	colors[247].r = 255;
	colors[247].g = 0;
	colors[247].b = 255;
	//light yellow
	colors[246].r = 255;
	colors[246].g = 255;
	colors[246].b = 220;
	//dark blue
	colors[245].r = 35;
	colors[245].g = 39;
	colors[245].b = 199;
	//dark gray
	colors[244].r = 60;
	colors[244].g = 60;
	colors[244].b = 60;
	//light gray
	colors[243].r = 200;
	colors[243].g = 200;
	colors[243].b = 200;
	//some sort of teal (cursor color)
	colors[242].r = 20;
	colors[242].g = 180;
	colors[242].b = 160;
	//yellow (selected file color)
	colors[241].r = 250;
	colors[241].g = 250;
	colors[241].b = 10;
	//menus, some sort of tan
	colors[240].r = 212;
	colors[240].g = 208;
	colors[240].b = 200;
	//medium gray
	colors[239].r = 120;
	colors[239].g = 120;
	colors[239].b = 120;
	//menu title
	colors[238].r = 40;
	colors[238].g = 60;
	colors[238].b = 160;

	SDL_SetPalette (screen, SDL_LOGPAL | SDL_PHYSPAL, colors, 0, 256);
	SDL_EnableUNICODE(1);

	seed = time (NULL);
	srand (seed);

	clear_menus();
	init_menus();
	init_groups();
	init_editors_viewers();
	init_bottom_buttons();
	init_sort_menu_entries();

/*
	{
		char test_str[1024];
		wchar_t test_dst[1024];

		wcscpy(test_dst, L" very long line where we are trying to see how this shit is going to look like. I really hope it is going to be OK, or else it is going to kind of suck pretty bad... 1234567890");

		wcstombs(test_str, test_dst, 1024);
		set_error("Pula mea..",test_str);
	//set_error("Pula mea.."," very long line where we are trying to see how this shit is going to look like. I really hope it is going to be OK, or else it is going to kind of suck pretty bad... 1234567890");
	}
*/

	while(1)
	{
		if(events_loop())break;

		if(update_screen)
			{
				update_screen=0;
				draw_main_screen(screen);
				display_menus();
				if(tooltip_text[0])draw_tooltip(screen, C_WHITE, tooltip_x, tooltip_y,  C_BLACK, tooltip_text);

				SDL_UpdateRect (screen, 0, 0, 0, 0);	//blit
			}

#ifdef WINDOWS
		Sleep(5);
#else
        usleep(5000);
#endif
	}

	save_settings();
	TTF_Quit();
	SDL_Quit();

  //if (cursors_mem)free(cursors_mem);
  return 1;
}

#ifdef WINDOWS

// splits a char* into a char ** based on the delimiters
int makeargv(char *s, char *delimiters, char ***argvp)
{
	int i, numtokens;
	char *snew, *t;

	if ((s == NULL) || (delimiters == NULL) || (argvp == NULL))
		return -1;

	*argvp = NULL;
	snew = s + strspn(s, delimiters);
	if ((t = malloc(strlen(snew) + 1)) == NULL)
		return -1;
	strcpy(t, snew);	// It's fine that this isn't strncpy, since t is sizeof(snew) + 1.

	numtokens = 0;
	if (strtok(t, delimiters) != NULL)
		for (numtokens = 1; strtok(NULL, delimiters) != NULL; numtokens++);

	if ((*argvp = malloc((numtokens + 1)*sizeof(char *))) == NULL){
		free(t);
		return -1;
	}
	if (numtokens == 0)
		free(t);
	else{
		strcpy(t, snew);
		**argvp = strtok(t, delimiters);
		for (i = 1; i < numtokens; i++)
			*((*argvp) + i) = strtok(NULL, delimiters);
	}
	*((*argvp) + numtokens) = NULL;
	return numtokens;
}
//frees the char** created by makeargv
void freemakeargv(char **argv)
{
	if (argv == NULL)
		return;
	if (*argv != NULL)
		free(*argv);
	free(argv);
}

int STDCALL WinMain (HINSTANCE hInst, HINSTANCE hPrev, LPSTR lpCmd, int nShow)
{
	char   *win_command_line;
	char **argv= NULL;
	int argc;

	win_command_line = GetCommandLine();
	argc = makeargv(win_command_line, " \t\n", &argv);

	Main(argc, (char **) argv);
	freemakeargv(argv);

	return 0;
}
#endif






