#include <sys/stat.h>
#include <errno.h>
#include "global.h"

char new_dir_text[128];

int cursor_pos=0;
int cursor_loc=0;

int mkdir_ok_button;
int mkdir_cancel_button;

int copy_ok_button;
int copy_cancel_button;

int delete_ok_button;
int delete_cancel_button;

int deleting_cancel_button;

int error_ok_button;
int error_cancel_button;
int error_ignore_button;

#define ERROR_CANCEL 0
#define ERROR_OK 1
#define ERROR_IGNORE 2

int error_selected_button;

int copying_cancel_button;

#define OVERWRITE_YES 0
#define OVERWRITE_NO 1
#define OVERWRITE_ALL 2
#define OVERWRITE_NONE 3
#define OVERWRITE_CANCEL 4

int overwrite_yes_button;
int overwrite_no_button;
int overwrite_all_button;
int overwrite_none_button;
int overwrite_cancel_button;

int overwrite_selected_button;

#define CONFIGURE_OK 0
#define CONFIGURE_CANCEL 1
#define CONFIGURE_GROUPS 2
#define CONFIGURE_COLORS 3
#define CONFIGURE_DEFAULT_EDITOR 4
#define CONFIGURE_DEFAULT_VIEWER 5
#define CONFIGURE_HEX_VIEWER 6

int config_selected_button=CONFIGURE_OK;

int config_ok_button;
int configure_cancel_button;

char delete_string[MAX_PATH];

int tooltip_x;
int tooltip_y;
char tooltip_text[500];

void set_error(char *main_error, char *aux_error)
{
	update_screen=1;
	error_selected_button=ERROR_OK;
	error_decision=ERROR_DECISSION_PENDING;
	menus[error_menu_id].opened=1;
	strcpy(error_text,main_error);
	strcpy(aux_error_text,aux_error);

}


void format_errno_error(char *str)
{
	if(errno==EPERM)
	strcpy(str,"Operation not permited.");
	else
	if(errno==EACCES)
	strcpy(str,"Permission denied.");
	else
	if(errno==EFAULT)
	strcpy(str,"Path points outside your accessible address space.");
	else
	if(errno==EIO)
	strcpy(str,"Some strange I/O error happened..");
#ifndef WINDOWS
	else
	if(errno==ELOOP)
	strcpy(str,"Too many sym links.");
#endif
	else
	if(errno==ENXIO)
	strcpy(str,"No such device or address.");
	else
	if(errno==ENAMETOOLONG)
	strcpy(str,"Path too long.");
	else
	if(errno==ENOENT)
	strcpy(str,"File/directory does not exist.");
	else
	if(errno==ENOMEM)
	strcpy(str,"Not enough memory..");
	else
	if(errno==ENOTDIR)
	strcpy(str,"Not a dir..");
	else
	if(errno==EEXIST)
	strcpy(str,"File or Directory already exists.");
	else
	if(errno==EMLINK)
	strcpy(str,"The parent directory has too many links entries.");
	else
	if(errno==ENOSPC)
	strcpy(str,"Not enough room.");
	else
	if(errno==EROFS)
	strcpy(str,"Parent directory is R/O.");
	else
	sprintf(str,"Unknown error, errno: %i",errno);

}

void format_chdir_error()
{
	char str[200];
	format_errno_error(str);
	set_error("Unable to change directory", str);
}

void format_mkdir_error()
{
	char str[200];
	format_errno_error(str);
	set_error("Unable to create directory", str);
}

void move_text_cursor_end(char * str,int max_len)
{
	int text_w,text_h;
	int i;
	char text_for_size[128];

	cursor_pos=strlen(str);

	//find out where it should be
	if(cursor_pos)
		{
			for(i=0;i<cursor_pos;i++)
			text_for_size[i]=str[i];

			text_for_size[i]=0;

			my_TTF_SizeText(font_default, text_for_size, &text_w, &text_h);
			cursor_loc=text_w;
		}
	else cursor_loc=0;
}

void keyboard_write_string(char * str, Uint8 ascii, int max_len)
{
	int text_w,text_h;
	int i;
	char text_for_size[128];

	Uint8 * key;
	key=SDL_GetKeyState(NULL);

	if(ascii>=32 && ascii<127)
		{
			if(cursor_pos<max_len && cursor_pos==strlen(str))
				{
					str[cursor_pos]=ascii;
					cursor_pos++;
					str[cursor_pos]=0;
				}
			else
			if(strlen(str)<max_len)
				{
					char tmp_str[32];
					strcpy(tmp_str,&str[cursor_pos]);
					str[cursor_pos]=ascii;
					strcpy(&str[cursor_pos+1],tmp_str);

					cursor_pos++;

				}
		}

	if(key[SDLK_LEFT])
		{
			if(cursor_pos>0)cursor_pos--;
		}

	if(key[SDLK_RIGHT])
		{
			if(cursor_pos<max_len && cursor_pos<strlen(str))cursor_pos++;
		}

	if(key[SDLK_END])
		{
			cursor_pos=strlen(str);
		}

	if(key[SDLK_HOME])
		{
			cursor_pos=0;
		}

	if(key[SDLK_BACKSPACE])
		{

			if(cursor_pos>0 && cursor_pos<strlen(str))
				{
					strcpy(&str[cursor_pos-1],&str[cursor_pos]);
					cursor_pos--;
				}
			else
			if(cursor_pos>0)
				{
					cursor_pos--;
					str[cursor_pos]=0;
				}
		}

	//find out where it should be
	if(cursor_pos)
		{
			for(i=0;i<cursor_pos;i++)
			text_for_size[i]=str[i];

			text_for_size[i]=0;

			my_TTF_SizeText(font_default, text_for_size, &text_w, &text_h);
			cursor_loc=text_w;
		}
	else cursor_loc=0;
}

#define MKDIR_OK_X_OFF 100
#define MKDIR_OK_Y_OFF 110
#define MKDIR_OK_X_LEN 70
#define MKDIR_OK_Y_LEN 22

#define MKDIR_CANCEL_X_OFF 180
#define MKDIR_CANCEL_Y_OFF 110
#define MKDIR_CANCEL_X_LEN 70
#define MKDIR_CANCEL_Y_LEN 22

void click_mkdir_ok()
{
	int result;

	if(new_dir_text[0])
		{
#ifndef WINDOWS
			result=mkdir(new_dir_text,(S_IRWXU|S_IRWXG|S_IRWXO));
#else
			result=mkdir(new_dir_text);
#endif
		}

	if(result==-1)
		{
			format_mkdir_error();
		}

	menus[mkdir_menu_id].opened=0;
	new_dir_text[0]=0;
	cursor_pos=0;
	cursor_loc=0;

	panels[active_panel].dir_path[0]=0;//force a reread/refresh
	panels[active_panel].cursor_file=0;
}

void click_mkdir_cancel()
{
	menus[mkdir_menu_id].opened=0;
	new_dir_text[0]=0;
	cursor_pos=0;
	cursor_loc=0;
}

void draw_mkdir_menu()
{
	draw_menu_window(screen,menus[mkdir_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[mkdir_menu_id].x_1, menus[mkdir_menu_id].y_1, menus[mkdir_menu_id].x_2-menus[mkdir_menu_id].x_1, menus[mkdir_menu_id].y_2-menus[mkdir_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);

	draw_description_frame(screen, " Directory name ", menus[mkdir_menu_id].x_1+10, menus[mkdir_menu_id].y_1+40, 340, 60,C_MEDIUM_GRAY ,C_WHITE);

	//draw the text area
	draw_empty_menu(screen, C_WHITE, menus[mkdir_menu_id].x_1+20, menus[mkdir_menu_id].y_1+60, 320, 20, C_MEDIUM_GRAY, C_WHITE);
	draw_empty_menu(screen, C_WHITE, menus[mkdir_menu_id].x_1+21, menus[mkdir_menu_id].y_1+61, 318, 18, C_DARK_GRAY, C_LIGHT_GRAY);

	TTF_DrawText(screen, font_default,menus[mkdir_menu_id].x_1+23,menus[mkdir_menu_id].y_1+64,C_BLACK,new_dir_text,315);

	//draw the cursor
	//if(SDL_GetTicks()&0x200)
	TTF_DrawText(screen, font_default,menus[mkdir_menu_id].x_1+23+cursor_loc,menus[mkdir_menu_id].y_1+63,C_BLACK,"|",10);

	//draw the buttons
	if(!mkdir_ok_button)draw_frame_button(screen, menus[mkdir_menu_id].x_1+MKDIR_OK_X_OFF, menus[mkdir_menu_id].y_1+MKDIR_OK_Y_OFF, MKDIR_OK_X_LEN, MKDIR_OK_Y_LEN, C_WHITE, C_DARK_GRAY, C_MEDIUM_GRAY);
	else draw_frame_button(screen, menus[mkdir_menu_id].x_1+MKDIR_OK_X_OFF, menus[mkdir_menu_id].y_1+MKDIR_OK_Y_OFF, MKDIR_OK_X_LEN, MKDIR_OK_Y_LEN, C_DARK_GRAY,C_WHITE,C_MEDIUM_GRAY);
	TTF_DrawText(screen, font_default,menus[mkdir_menu_id].x_1+MKDIR_OK_X_OFF+30,menus[mkdir_menu_id].y_1+MKDIR_OK_Y_OFF+5,C_BLACK,"Ok",315);

	if(!mkdir_cancel_button)draw_frame_button(screen, menus[mkdir_menu_id].x_1+MKDIR_CANCEL_X_OFF, menus[mkdir_menu_id].y_1+MKDIR_CANCEL_Y_OFF, MKDIR_CANCEL_X_LEN, MKDIR_CANCEL_Y_LEN, C_WHITE, C_DARK_GRAY, C_MEDIUM_GRAY);
	else draw_frame_button(screen, menus[mkdir_menu_id].x_1+MKDIR_CANCEL_X_OFF, menus[mkdir_menu_id].y_1+MKDIR_CANCEL_Y_OFF, MKDIR_CANCEL_X_LEN, MKDIR_CANCEL_Y_LEN, C_DARK_GRAY,C_WHITE,C_MEDIUM_GRAY);
	TTF_DrawText(screen, font_default,menus[mkdir_menu_id].x_1+MKDIR_CANCEL_X_OFF+15,menus[mkdir_menu_id].y_1+MKDIR_CANCEL_Y_OFF+5,C_BLACK,"Cancel",315);


}

void click_mkdir_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	//OK button?
	if(mouse_x>=menus[mkdir_menu_id].x_1+MKDIR_OK_X_OFF && mouse_x<=menus[mkdir_menu_id].x_1+MKDIR_OK_X_OFF+MKDIR_OK_X_LEN && mouse_y>=menus[mkdir_menu_id].y_1+MKDIR_OK_Y_OFF &&
	mouse_y<=menus[mkdir_menu_id].y_1+MKDIR_OK_Y_OFF+MKDIR_OK_Y_LEN)
		{
			if(mkdir_ok_button && !left_b)//depressing left button
				{
					click_mkdir_ok();
					mkdir_ok_button=0;
					return;
				}

			if(left_b)
			mkdir_ok_button=1;
		}
		else
		mkdir_ok_button=0;

	//Cancel button?
	if(mouse_x>=menus[mkdir_menu_id].x_1+MKDIR_CANCEL_X_OFF && mouse_x<=menus[mkdir_menu_id].x_1+MKDIR_CANCEL_X_OFF+MKDIR_CANCEL_X_LEN && mouse_y>=menus[mkdir_menu_id].y_1+MKDIR_CANCEL_Y_OFF &&
	mouse_y<=menus[mkdir_menu_id].y_1+MKDIR_CANCEL_Y_OFF+MKDIR_CANCEL_Y_LEN)
		{
			if(mkdir_cancel_button && !left_b)//depressing left button
				{
					click_mkdir_cancel();
					mkdir_cancel_button=0;
					return;
				}

			if(left_b)
			mkdir_cancel_button=1;
		}
		else
		mkdir_cancel_button=0;
}

void mkdir_menu_keypresses(Uint8 ascii)
{
	Uint8 * key;
	key=SDL_GetKeyState(NULL);

	if(key[SDLK_RETURN])
		{
			click_mkdir_ok();
			return;
		}

	if(key[SDLK_ESCAPE])
		{
			click_mkdir_cancel();
		}

	keyboard_write_string(new_dir_text,ascii, 127);
}



void draw_calculating_size_menu()
{
	char str[64];
	int text_w,text_h;
	int x_text,y_text;

	draw_empty_menu(screen, C_MENU_COLOR, menus[calculating_size_menu_id].x_1, menus[calculating_size_menu_id].y_1, menus[calculating_size_menu_id].x_2-menus[calculating_size_menu_id].x_1, menus[calculating_size_menu_id].y_2-menus[calculating_size_menu_id].y_1,  C_BLACK, C_BLACK);

	format_number(files_size,str,(decimal_separator) ? '.':',');

	my_TTF_SizeText(font_default, str, &text_w, &text_h);

	x_text=((menus[calculating_size_menu_id].x_2-menus[calculating_size_menu_id].x_1)-text_w)/2;
	y_text=((menus[calculating_size_menu_id].y_2-menus[calculating_size_menu_id].y_1)-text_h)/2;

	TTF_DrawText(screen, font_default,menus[calculating_size_menu_id].x_1+x_text,menus[calculating_size_menu_id].y_1+y_text,C_BLACK,str,menus[sort_menu_id].x_2-menus[sort_menu_id].x_1);
}

void draw_sort_menu()
{
	int i;

	draw_menu_window(screen,menus[sort_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[sort_menu_id].x_1, menus[sort_menu_id].y_1, menus[sort_menu_id].x_2-menus[sort_menu_id].x_1, menus[sort_menu_id].y_2-menus[sort_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);

	for(i=0;i<SORT_MENU_ENTRIES;i++)
	if(menus[sort_menu_id].mouse_over_element==i)
		{
			draw_line(screen, menus[sort_menu_id].x_1+2, menus[sort_menu_id].y_1+24+16*i, 16, menus[sort_menu_id].x_2-menus[sort_menu_id].x_1-4, C_DARK_BLUE);
			TTF_DrawText(screen, font_default,menus[sort_menu_id].x_1+5,menus[sort_menu_id].y_1+26+16*i,C_WHITE,sort_menu_entries[i].name,menus[sort_menu_id].x_2-menus[sort_menu_id].x_1);
		}
	else
		TTF_DrawText(screen, font_default,menus[sort_menu_id].x_1+5,menus[sort_menu_id].y_1+26+16*i,C_BLACK,sort_menu_entries[i].name,menus[sort_menu_id].x_2-menus[sort_menu_id].x_1);
}

void click_sort_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	int i;
	int offset_y=menus[sort_menu_id].y_1+24;

	if(!left_b)return;

	for(i=0;i<SORT_MENU_ENTRIES;i++)
	if(mouse_y>=offset_y+16*i && mouse_y<=offset_y+16+16*i)
		{
			panels[active_panel].sort_type=sort_menu_entries[i].sort_type;
			panels[active_panel].needs_resort=1;
			menus[sort_menu_id].opened=0;
		}
}

void mouse_over_sort_menu(int mouse_x, int mouse_y)
{
	int i;
	int offset_y=menus[sort_menu_id].y_1+24;

	for(i=0;i<SORT_MENU_ENTRIES;i++)
	if(mouse_y>=offset_y+16*i && mouse_y<=offset_y+16+16*i)
		{
			if(menus[sort_menu_id].mouse_over_element!=i)update_screen=1;
			menus[sort_menu_id].mouse_over_element=i;
		}

}

void draw_bookmarks_menu()
{
	int i;

	draw_menu_window(screen,menus[bookmarks_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[bookmarks_menu_id].x_1, menus[bookmarks_menu_id].y_1, menus[bookmarks_menu_id].x_2-menus[bookmarks_menu_id].x_1, menus[bookmarks_menu_id].y_2-menus[bookmarks_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);

	for(i=0;i<last_menu_bookmark;i++)
	if(menus[bookmarks_menu_id].mouse_over_element==i)
		{
			draw_line(screen, menus[bookmarks_menu_id].x_1+2, menus[bookmarks_menu_id].y_1+24+16*i, 16, menus[bookmarks_menu_id].x_2-menus[bookmarks_menu_id].x_1-4, C_DARK_BLUE);
			TTF_DrawText(screen, font_default,menus[bookmarks_menu_id].x_1+5,menus[bookmarks_menu_id].y_1+26+16*i,C_WHITE,bookmark_menu_entries[i].name,menus[bookmarks_menu_id].x_2-menus[bookmarks_menu_id].x_1);
		}
	else
		TTF_DrawText(screen, font_default,menus[bookmarks_menu_id].x_1+5,menus[bookmarks_menu_id].y_1+26+16*i,C_BLACK,bookmark_menu_entries[i].name,menus[bookmarks_menu_id].x_2-menus[bookmarks_menu_id].x_1);
}

void click_bookmarks_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	int i,j;
	int offset_y=menus[bookmarks_menu_id].y_1+24;
	char path_name[256];

	if(!left_b && !right_b)return;

	for(i=0;i<last_menu_bookmark;i++)
	if(mouse_y>=offset_y+16*i && mouse_y<=offset_y+16+16*i)
		{
			//remove bookmark?
			if((shift_on || right_b) && bookmark_menu_entries[i].type==BOOKMARK_DIR)
				{
					for(j=0;j<last_bookmark;j++)
					if(!strcmp(bookmarks[j].name,bookmark_menu_entries[i].name))
						{
							if(j==last_bookmark-1)
								{
									last_bookmark--;
								}
							else
								{
									strcpy(bookmarks[j].name,bookmarks[last_bookmark-1].name);
									last_bookmark--;
								}
							break;
						}

					menus[bookmarks_menu_id].opened=0;
					return;
				}

			if(bookmark_menu_entries[i].type!=BOOKMARK_ADD_BOOKMARK)
				{
					if(bookmark_menu_entries[i].type==BOOKMARK_DRIVE)
					sprintf(path_name,"%c:\\",bookmark_menu_entries[i].name[0]);
					else
					strcpy(path_name,bookmark_menu_entries[i].name);

					if(!chdir(path_name))
						{
							panels[active_panel].dir_path[0]=0;//force a reread/refresh
							panels[active_panel].cursor_file=0;
						}
					else
					format_chdir_error();
				}
			else//add bookmark
				{
					strcpy(bookmarks[last_bookmark].name,panels[active_panel].dir_path);
					last_bookmark++;
				}

			menus[bookmarks_menu_id].opened=0;
		}
}

void mouse_over_bookmarks_menu(int mouse_x, int mouse_y)
{
	int i;
	int offset_y=menus[bookmarks_menu_id].y_1+24;

	for(i=0;i<last_menu_bookmark;i++)
	if(mouse_y>=offset_y+16*i && mouse_y<=offset_y+16+16*i)
		{
			if(menus[bookmarks_menu_id].mouse_over_element!=i)update_screen=1;
			menus[bookmarks_menu_id].mouse_over_element=i;
		}

}

void open_bookmarks_menu()
{
	int i;
	int drives;
	int x_size;
	int y_size;
	int xpanel;
	int ypanel;
	int drive_type;
	int len;
	int max_len=0;
	char drive_str[16];
	char drive_type_str[32];

	last_menu_bookmark=0;

#ifdef WINDOWS

	drives=GetLogicalDrives();

	for(i=0;i<32;i++)
		{
			Uint32 mask=1;
			mask<<=i;

			if((drives&mask))
				{
					sprintf(drive_str,"%c:\\",65+i);
					drive_type=GetDriveType(drive_str);
					if(drive_type!= DRIVE_UNKNOWN && drive_type!= DRIVE_NO_ROOT_DIR)
						{
							if(drive_type==DRIVE_REMOVABLE)
							strcpy(drive_type_str,"[Removable]");
							else
							if(drive_type==DRIVE_FIXED)
							strcpy(drive_type_str,"[Fixed]");
							else
							if(drive_type==DRIVE_REMOTE)
							strcpy(drive_type_str,"[Network]");
							else
							if(drive_type==DRIVE_CDROM)
							strcpy(drive_type_str,"[CD-ROM]");
							else
							if(drive_type==DRIVE_RAMDISK)
							strcpy(drive_type_str,"[Ram disk]");

							sprintf(bookmark_menu_entries[last_menu_bookmark].name,"%c: %s",65+i,drive_type_str);
							bookmark_menu_entries[last_menu_bookmark].type=BOOKMARK_DRIVE;
							last_menu_bookmark++;
						}
				}
		}
#else
	strcpy(bookmark_menu_entries[last_menu_bookmark].name,"/");
	bookmark_menu_entries[last_menu_bookmark].type=BOOKMARK_DIR;
	last_menu_bookmark++;
	sprintf(bookmark_menu_entries[last_menu_bookmark].name,"%s",getenv("HOME"));
	bookmark_menu_entries[last_menu_bookmark].type=BOOKMARK_DIR;
	last_menu_bookmark++;
#endif

	for(i=0;i<last_bookmark;i++)
		{
			strcpy(bookmark_menu_entries[last_menu_bookmark].name,bookmarks[i].name);
			bookmark_menu_entries[last_menu_bookmark].type=BOOKMARK_DIR;
			last_menu_bookmark++;
		}

	strcpy(bookmark_menu_entries[last_menu_bookmark].name,"Bookmark current dir");
	bookmark_menu_entries[last_menu_bookmark].type=BOOKMARK_ADD_BOOKMARK;
	last_menu_bookmark++;


	menus[bookmarks_menu_id].opened=1;

	//calculate the size of this menu
	for(i=0;i<last_menu_bookmark;i++)
		{
			int text_height;//not used

			my_TTF_SizeText(font_default, bookmark_menu_entries[i].name, &len, &text_height);
			if(len>max_len)max_len=len;
		}

	x_size=max_len+10;
	if(x_size<100)x_size=100;

	y_size=last_menu_bookmark*16+28;

	xpanel=panels[active_panel].x_pos_1;
	ypanel=panels[active_panel].y_pos_1;

	menus[bookmarks_menu_id].x_1=xpanel+20;
	menus[bookmarks_menu_id].x_2=xpanel+20+x_size;
	menus[bookmarks_menu_id].y_1=ypanel+25;
	menus[bookmarks_menu_id].y_2=ypanel+25+y_size;

}

#define ERROR_CANCEL_X_OFF 70
#define ERROR_CANCEL_Y_OFF 80
#define ERROR_CANCEL_X_LEN 70
#define ERROR_CANCEL_Y_LEN 22

#define ERROR_OK_X_OFF ERROR_CANCEL_X_OFF+ERROR_CANCEL_X_LEN+6
#define ERROR_OK_Y_OFF 80
#define ERROR_OK_X_LEN 70
#define ERROR_OK_Y_LEN 22

#define ERROR_IGNORE_X_OFF ERROR_OK_X_OFF+ERROR_OK_X_LEN+6
#define ERROR_IGNORE_Y_OFF 80
#define ERROR_IGNORE_X_LEN 70
#define ERROR_IGNORE_Y_LEN 22

void draw_error_menu()
{
	int text_width;
	int text_height;
	int text_x_pos;

	my_TTF_SizeText(font_bold, error_text, &text_width, &text_height);
	text_x_pos=((menus[error_menu_id].x_2-menus[error_menu_id].x_1)-text_width)/2;

	draw_menu_window(screen,menus[error_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[error_menu_id].x_1, menus[error_menu_id].y_1, menus[error_menu_id].x_2-menus[error_menu_id].x_1, menus[error_menu_id].y_2-menus[error_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);

	TTF_DrawText(screen, font_bold,menus[error_menu_id].x_1+text_x_pos,menus[error_menu_id].y_1+25,C_BLACK,error_text,380);
	TTF_DrawText_multiple_lines(screen, font_default,menus[error_menu_id].x_1+10,menus[error_menu_id].y_1+38,C_BLACK,aux_error_text,380,3);

	//draw the buttons
	draw_button(screen, "Ok", menus[error_menu_id].x_1+ERROR_OK_X_OFF, menus[error_menu_id].y_1+ERROR_OK_Y_OFF, ERROR_OK_X_LEN, ERROR_OK_Y_LEN, error_ok_button, (error_selected_button==ERROR_OK) ? 1:0);
	draw_button(screen, "Cancel", menus[error_menu_id].x_1+ERROR_CANCEL_X_OFF, menus[error_menu_id].y_1+ERROR_CANCEL_Y_OFF, ERROR_CANCEL_X_LEN, ERROR_CANCEL_Y_LEN, error_cancel_button, (error_selected_button==ERROR_CANCEL) ? 1:0);
	draw_button(screen, "Ignore all", menus[error_menu_id].x_1+ERROR_IGNORE_X_OFF, menus[error_menu_id].y_1+ERROR_IGNORE_Y_OFF, ERROR_IGNORE_X_LEN, ERROR_IGNORE_Y_LEN, error_ignore_button, (error_selected_button==ERROR_IGNORE) ? 1:0);


}

void click_error_cancel()
{
	menus[error_menu_id].opened=0;
	error_text[0]=0;
	aux_error_text[0]=0;
	error_decision=ERROR_DECISSION_CANCEL;
}

void click_error_ok()
{
	menus[error_menu_id].opened=0;
	error_text[0]=0;
	aux_error_text[0]=0;
	error_decision=ERROR_DECISSION_OK;
}

void click_error_ignore()
{
	menus[error_menu_id].opened=0;
	error_text[0]=0;
	aux_error_text[0]=0;
	error_decision=ERROR_DECISSION_IGNORE;
}

void error_menu_keypresses(Uint8 ascii)
{
	Uint8 * key;
	key=SDL_GetKeyState(NULL);

	if(key[SDLK_RIGHT])
		{
			error_selected_button++;
			if(error_selected_button>ERROR_IGNORE)error_selected_button=0;
			return;
		}

	if(key[SDLK_LEFT])
		{
			error_selected_button--;
			if(error_selected_button<0)error_selected_button=ERROR_IGNORE;
			return;
		}

	if(key[SDLK_RETURN])
		{
			if(error_selected_button==ERROR_DECISSION_OK)
			click_error_ok();
			else
			if(error_selected_button==ERROR_DECISSION_IGNORE)
			click_error_ignore();
			else
			if(error_selected_button==ERROR_DECISSION_CANCEL)
			click_error_cancel();
			return;
		}

	if(key[SDLK_ESCAPE])
		{
			click_error_cancel();
			return;
		}

}

void click_error_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	//OK button?
	if(mouse_x>=menus[error_menu_id].x_1+ERROR_OK_X_OFF && mouse_x<=menus[error_menu_id].x_1+ERROR_OK_X_OFF+ERROR_OK_X_LEN && mouse_y>=menus[error_menu_id].y_1+ERROR_OK_Y_OFF &&
	mouse_y<=menus[error_menu_id].y_1+ERROR_OK_Y_OFF+ERROR_OK_Y_LEN)
		{
			if(error_ok_button && !left_b)//depressing left button
				{
					click_error_ok();
					error_ok_button=0;
					return;
				}

			if(left_b)
			error_ok_button=1;
		}
		else
		error_ok_button=0;

	//Cancel button?
	if(mouse_x>=menus[error_menu_id].x_1+ERROR_CANCEL_X_OFF && mouse_x<=menus[error_menu_id].x_1+ERROR_CANCEL_X_OFF+ERROR_CANCEL_X_LEN && mouse_y>=menus[error_menu_id].y_1+ERROR_CANCEL_Y_OFF &&
	mouse_y<=menus[error_menu_id].y_1+ERROR_CANCEL_Y_OFF+ERROR_CANCEL_Y_LEN)
		{
			if(error_cancel_button && !left_b)//depressing left button
				{
					click_error_cancel();
					error_cancel_button=0;
					return;
				}

			if(left_b)
			error_cancel_button=1;
		}
		else
		error_cancel_button=0;

	//Ignore button?
	if(mouse_x>=menus[error_menu_id].x_1+ERROR_IGNORE_X_OFF && mouse_x<=menus[error_menu_id].x_1+ERROR_IGNORE_X_OFF+ERROR_IGNORE_X_LEN && mouse_y>=menus[error_menu_id].y_1+ERROR_IGNORE_Y_OFF &&
	mouse_y<=menus[error_menu_id].y_1+ERROR_IGNORE_Y_OFF+ERROR_IGNORE_Y_LEN)
		{
			if(error_ignore_button && !left_b)//depressing left button
				{
					click_error_ignore();
					error_ignore_button=0;
					return;
				}

			if(left_b)
			error_ignore_button=1;
		}
		else
		error_ignore_button=0;
}

#define DELETE_OK_X_OFF 110
#define DELETE_OK_Y_OFF 120
#define DELETE_OK_X_LEN 70
#define DELETE_OK_Y_LEN 22

#define DELETE_CANCEL_X_OFF 190
#define DELETE_CANCEL_Y_OFF 120
#define DELETE_CANCEL_X_LEN 70
#define DELETE_CANCEL_Y_LEN 22

void click_delete_ok()
{
	SDL_Thread *thread;

	menus[delete_menu_id].opened=0;

	menus[deleting_menu_id].opened=1;
	SDL_CreateThread(delete_files, NULL);
}

void click_delete_cancel()
{
	menus[delete_menu_id].opened=0;
}

void delete_menu_keypresses(Uint8 ascii)
{
	Uint8 * key;
	key=SDL_GetKeyState(NULL);

	if(key[SDLK_RETURN])
		{
			click_delete_ok();
			return;
		}

	if(key[SDLK_ESCAPE])
		{
			click_delete_cancel();
		}
}

void click_delete_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	//OK button?
	if(mouse_x>=menus[delete_menu_id].x_1+DELETE_OK_X_OFF && mouse_x<=menus[delete_menu_id].x_1+DELETE_OK_X_OFF+DELETE_OK_X_LEN && mouse_y>=menus[delete_menu_id].y_1+DELETE_OK_Y_OFF &&
	mouse_y<=menus[delete_menu_id].y_1+DELETE_OK_Y_OFF+DELETE_OK_Y_LEN)
		{
			if(delete_ok_button && !left_b)//depressing left button
				{
					click_delete_ok();
					delete_ok_button=0;
					return;
				}

			if(left_b)
			delete_ok_button=1;
		}
		else
		delete_ok_button=0;

	//Cancel button?
	if(mouse_x>=menus[delete_menu_id].x_1+DELETE_CANCEL_X_OFF && mouse_x<=menus[delete_menu_id].x_1+DELETE_CANCEL_X_OFF+DELETE_CANCEL_X_LEN && mouse_y>=menus[delete_menu_id].y_1+DELETE_CANCEL_Y_OFF &&
	mouse_y<=menus[delete_menu_id].y_1+DELETE_CANCEL_Y_OFF+DELETE_CANCEL_Y_LEN)
		{
			if(delete_cancel_button && !left_b)//depressing left button
				{
					click_delete_cancel();
					delete_cancel_button=0;
					return;
				}

			if(left_b)
			delete_cancel_button=1;
		}
		else
		delete_cancel_button=0;
}

void draw_delete_menu()
{
	draw_menu_window(screen,menus[delete_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[delete_menu_id].x_1, menus[delete_menu_id].y_1, menus[delete_menu_id].x_2-menus[delete_menu_id].x_1, menus[delete_menu_id].y_2-menus[delete_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);

	draw_description_frame(screen, "", menus[delete_menu_id].x_1+10, menus[delete_menu_id].y_1+27, 340, 80,C_MEDIUM_GRAY ,C_WHITE);

	TTF_DrawText(screen, font_default,menus[delete_menu_id].x_1+60,menus[delete_menu_id].y_1+40,C_BLACK,"Delete the following file or folder:",315);
	TTF_DrawText_multiple_lines(screen, font_default,menus[delete_menu_id].x_1+25,menus[delete_menu_id].y_1+55,C_BLACK,delete_string,315,3);

	//draw the buttons
	draw_button(screen, "OK", menus[delete_menu_id].x_1+DELETE_OK_X_OFF, menus[delete_menu_id].y_1+DELETE_OK_Y_OFF, DELETE_OK_X_LEN, DELETE_OK_Y_LEN, delete_ok_button, 1);

	draw_button(screen, "Cancel", menus[delete_menu_id].x_1+DELETE_CANCEL_X_OFF, menus[delete_menu_id].y_1+DELETE_CANCEL_Y_OFF, DELETE_CANCEL_X_LEN, DELETE_CANCEL_Y_LEN, delete_cancel_button, 0);
}

#define DELETING_CANCEL_X_OFF 140
#define DELETING_CANCEL_Y_OFF 120
#define DELETING_CANCEL_X_LEN 70
#define DELETING_CANCEL_Y_LEN 22

void click_deleting_cancel()
{
	cancel_delete=1;
	menus[deleting_menu_id].opened=0;
}

void deleting_menu_keypresses(Uint8 ascii)
{
	Uint8 * key;
	key=SDL_GetKeyState(NULL);

	if(key[SDLK_ESCAPE])
		{
			click_deleting_cancel();
		}
}

void click_deleting_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	//Cancel button?
	if(mouse_x>=menus[deleting_menu_id].x_1+DELETING_CANCEL_X_OFF && mouse_x<=menus[deleting_menu_id].x_1+DELETING_CANCEL_X_OFF+DELETING_CANCEL_X_LEN && mouse_y>=menus[deleting_menu_id].y_1+DELETING_CANCEL_Y_OFF &&
	mouse_y<=menus[deleting_menu_id].y_1+DELETING_CANCEL_Y_OFF+DELETING_CANCEL_Y_LEN)
		{
			if(deleting_cancel_button && !left_b)//depressing left button
				{
					click_deleting_cancel();
					deleting_cancel_button=0;
					return;
				}

			if(left_b)
			deleting_cancel_button=1;
		}
		else
		deleting_cancel_button=0;
}

void draw_deleting_menu()
{
	draw_menu_window(screen,menus[deleting_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[deleting_menu_id].x_1, menus[deleting_menu_id].y_1, menus[deleting_menu_id].x_2-menus[deleting_menu_id].x_1, menus[deleting_menu_id].y_2-menus[deleting_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);

	draw_description_frame(screen, "", menus[deleting_menu_id].x_1+10, menus[deleting_menu_id].y_1+27, 340, 80,C_MEDIUM_GRAY ,C_WHITE);

	TTF_DrawText(screen, font_default,menus[deleting_menu_id].x_1+100,menus[deleting_menu_id].y_1+30,C_BLACK,"Deleting file:",315);
	TTF_DrawText_multiple_lines(screen, font_default,menus[deleting_menu_id].x_1+25,menus[deleting_menu_id].y_1+45,C_BLACK,current_deleting_file,315,4);

	draw_button(screen, "Cancel", menus[deleting_menu_id].x_1+DELETING_CANCEL_X_OFF, menus[deleting_menu_id].y_1+DELETING_CANCEL_Y_OFF, DELETING_CANCEL_X_LEN, DELETING_CANCEL_Y_LEN, deleting_cancel_button, 1);
}


#define COPY_OK_X_OFF 120
#define COPY_OK_Y_OFF 140
#define COPY_OK_X_LEN 70
#define COPY_OK_Y_LEN 22

#define COPY_CANCEL_X_OFF 200
#define COPY_CANCEL_Y_OFF 140
#define COPY_CANCEL_X_LEN 70
#define COPY_CANCEL_Y_LEN 22

void click_copy_ok()
{
	SDL_Thread *thread;

	menus[copy_menu_id].opened=0;
	cursor_pos=0;
	cursor_loc=0;

	if(!move_instead_of_copy)
		{
			menus[copying_menu_id].opened=1;
			SDL_CreateThread(copy_files, NULL);
		}
	else
	SDL_CreateThread(move_files, NULL);
}

void click_copy_cancel()
{
	menus[copy_menu_id].opened=0;
	cursor_pos=0;
	cursor_loc=0;
}

void draw_copy_menu()
{
	draw_menu_window(screen,menus[copy_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[copy_menu_id].x_1, menus[copy_menu_id].y_1, menus[copy_menu_id].x_2-menus[copy_menu_id].x_1, menus[copy_menu_id].y_2-menus[copy_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);

	draw_description_frame(screen, "", menus[copy_menu_id].x_1+6, menus[copy_menu_id].y_1+27, 388, 100,C_MEDIUM_GRAY ,C_WHITE);

	//draw the FROM text area
	TTF_DrawText(screen, font_default,menus[copy_menu_id].x_1+10,menus[copy_menu_id].y_1+45,C_BLACK,"From:",315);
	draw_empty_menu(screen, C_WHITE, menus[copy_menu_id].x_1+45, menus[copy_menu_id].y_1+40, 340, 20, C_MEDIUM_GRAY, C_WHITE);
	draw_empty_menu(screen, C_WHITE, menus[copy_menu_id].x_1+46, menus[copy_menu_id].y_1+41, 338, 18, C_DARK_GRAY, C_LIGHT_GRAY);
	TTF_DrawText(screen, font_default,menus[copy_menu_id].x_1+48,menus[copy_menu_id].y_1+45,C_MEDIUM_GRAY,source_copy_text,315);

	//draw the TO text area
	TTF_DrawText(screen, font_default,menus[copy_menu_id].x_1+10,menus[copy_menu_id].y_1+80,C_BLACK,"To:",315);
	draw_empty_menu(screen, C_WHITE, menus[copy_menu_id].x_1+45, menus[copy_menu_id].y_1+75, 340, 20, C_MEDIUM_GRAY, C_WHITE);
	draw_empty_menu(screen, C_WHITE, menus[copy_menu_id].x_1+46, menus[copy_menu_id].y_1+76, 338, 18, C_DARK_GRAY, C_LIGHT_GRAY);
	TTF_DrawText(screen, font_default,menus[copy_menu_id].x_1+48,menus[copy_menu_id].y_1+80,C_BLACK,dest_copy_text,315);

	//draw the cursor
	//if(SDL_GetTicks()&0x200)
	TTF_DrawText(screen, font_default,menus[copy_menu_id].x_1+47+cursor_loc,menus[copy_menu_id].y_1+80,C_BLACK,"|",10);

	//draw the buttons
	if(!copy_ok_button)draw_frame_button(screen, menus[copy_menu_id].x_1+COPY_OK_X_OFF, menus[copy_menu_id].y_1+COPY_OK_Y_OFF, COPY_OK_X_LEN, COPY_OK_Y_LEN, C_WHITE, C_DARK_GRAY, C_MEDIUM_GRAY);
	else draw_frame_button(screen, menus[copy_menu_id].x_1+COPY_OK_X_OFF, menus[copy_menu_id].y_1+COPY_OK_Y_OFF, COPY_OK_X_LEN, COPY_OK_Y_LEN, C_DARK_GRAY,C_WHITE,C_MEDIUM_GRAY);
	TTF_DrawText(screen, font_default,menus[copy_menu_id].x_1+COPY_OK_X_OFF+30,menus[copy_menu_id].y_1+COPY_OK_Y_OFF+5,C_BLACK,"Ok",315);

	if(!copy_cancel_button)draw_frame_button(screen, menus[copy_menu_id].x_1+COPY_CANCEL_X_OFF, menus[copy_menu_id].y_1+COPY_CANCEL_Y_OFF, COPY_CANCEL_X_LEN, COPY_CANCEL_Y_LEN, C_WHITE, C_DARK_GRAY, C_MEDIUM_GRAY);
	else draw_frame_button(screen, menus[copy_menu_id].x_1+COPY_CANCEL_X_OFF, menus[copy_menu_id].y_1+COPY_CANCEL_Y_OFF, COPY_CANCEL_X_LEN, COPY_CANCEL_Y_LEN, C_DARK_GRAY,C_WHITE,C_MEDIUM_GRAY);
	TTF_DrawText(screen, font_default,menus[copy_menu_id].x_1+COPY_CANCEL_X_OFF+15,menus[copy_menu_id].y_1+COPY_CANCEL_Y_OFF+5,C_BLACK,"Cancel",315);

}

void click_copy_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	//OK button?
	if(mouse_x>=menus[copy_menu_id].x_1+COPY_OK_X_OFF && mouse_x<=menus[copy_menu_id].x_1+COPY_OK_X_OFF+COPY_OK_X_LEN && mouse_y>=menus[copy_menu_id].y_1+COPY_OK_Y_OFF &&
	mouse_y<=menus[copy_menu_id].y_1+COPY_OK_Y_OFF+COPY_OK_Y_LEN)
		{
			if(copy_ok_button && !left_b)//depressing left button
				{
					click_copy_ok();
					copy_ok_button=0;
					return;
				}

			if(left_b)
			copy_ok_button=1;
		}
		else
		copy_ok_button=0;

	//Cancel button?
	if(mouse_x>=menus[copy_menu_id].x_1+COPY_CANCEL_X_OFF && mouse_x<=menus[copy_menu_id].x_1+COPY_CANCEL_X_OFF+COPY_CANCEL_X_LEN && mouse_y>=menus[copy_menu_id].y_1+COPY_CANCEL_Y_OFF &&
	mouse_y<=menus[copy_menu_id].y_1+COPY_CANCEL_Y_OFF+COPY_CANCEL_Y_LEN)
		{
			if(copy_cancel_button && !left_b)//depressing left button
				{
					click_copy_cancel();
					copy_cancel_button=0;
					return;
				}

			if(left_b)
			copy_cancel_button=1;
		}
		else
		copy_cancel_button=0;
}

void copy_menu_keypresses(Uint8 ascii)
{
	Uint8 * key;
	key=SDL_GetKeyState(NULL);

	if(key[SDLK_RETURN])
		{
			click_copy_ok();
			return;
		}

	if(key[SDLK_ESCAPE])
		{
			click_copy_cancel();
		}

	keyboard_write_string(dest_copy_text,ascii, 1024);
}

void pre_open_copy_menu_drag(int from_panel, int to_panel, int selected_location)
{
	int selected_dirs=0;
	int selected_files=0;
	int i;
	char *file_name;
	int text_w,text_h;
	char some_char;

 	//source_copy_text
 	some_char=panels[to_panel].dir_path[strlen(panels[to_panel].dir_path)-1];
	strcpy(dest_copy_text,panels[to_panel].dir_path);
	if(some_char!='\\' && some_char!='/')
		{
#ifdef WINDOWS
			strcat(dest_copy_text,"\\");
#else
			strcat(dest_copy_text,"/");
#endif
		}

	//destination is a directory or just the panel?
	if(selected_location<=panels[to_panel].number_of_files)
	if(panels[to_panel].panel_files[panels[to_panel].panel_files_order[selected_location]].is_dir)
		{
			strcat(dest_copy_text,panels[to_panel].panel_files[panels[to_panel].panel_files_order[selected_location]].name);
#ifdef WINDOWS
			strcat(dest_copy_text,"\\");
#else
			strcat(dest_copy_text,"/");
#endif
		}
	else
		{
			//click in the same panel and not in a directory
			if(from_panel==to_panel)return;
		}

	for(i=0;i<panels[from_panel].number_of_files;i++)
	if(panels[from_panel].panel_files[i].selected)
		{
			if(panels[from_panel].panel_files[i].is_dir)
	 		selected_dirs++;
	 		else
	 		selected_files++;
		}

	if(selected_files || selected_dirs)
		{
			if(selected_files && !selected_dirs)
			sprintf(source_copy_text,"%i files(s)",selected_files);
			else
			if(!selected_files && selected_dirs)
			sprintf(source_copy_text,"%i directories",selected_dirs);
			else
			sprintf(source_copy_text,"%i file(s) and %i directories",selected_files,selected_dirs);
		}
	else
		{
			file_name=panels[from_panel].panel_files[panels[from_panel].panel_files_order[panels[from_panel].cursor_file]].name;

			//is it the parent directory?
			if(file_name[0]=='.' && file_name[1]=='.')
				{
					menus[copy_menu_id].opened=0;
					return;
				}

			strcpy(source_copy_text,panels[from_panel].dir_path);

			some_char=panels[from_panel].dir_path[strlen(panels[from_panel].dir_path)-1];
			if(some_char!='\\' && some_char!='/')
				{
#ifdef WINDOWS
					strcat(source_copy_text,"\\");
#else
					strcat(source_copy_text,"/");
#endif
				}
			strcat(source_copy_text,file_name);
		}

	cursor_pos=strlen(dest_copy_text);
	my_TTF_SizeText(font_default, dest_copy_text, &text_w, &text_h);
	cursor_loc=text_w;
	menus[copy_menu_id].opened=1;
}

void pre_open_copy_menu()
{
	int dst_panel=!active_panel;
	int selected_dirs=0;
	int selected_files=0;
	int i;
	char *file_name;
	int text_w,text_h;
	char some_char;

 	//source_copy_text
	strcpy(dest_copy_text,panels[dst_panel].dir_path);
 	some_char=panels[dst_panel].dir_path[strlen(panels[dst_panel].dir_path)-1];
	if(some_char!='\\' && some_char!='/')
		{
#ifdef WINDOWS
			strcat(dest_copy_text,"\\");
#else
			strcat(dest_copy_text,"/");
#endif
		}

	for(i=0;i<panels[active_panel].number_of_files;i++)
	if(panels[active_panel].panel_files[i].selected)
		{
			if(panels[active_panel].panel_files[i].is_dir)
	 		selected_dirs++;
	 		else
	 		selected_files++;
		}

	if(selected_files || selected_dirs)
		{
			if(selected_files && !selected_dirs)
			sprintf(source_copy_text,"%i files(s)",selected_files);
			else
			if(!selected_files && selected_dirs)
			sprintf(source_copy_text,"%i directories",selected_dirs);
			else
			sprintf(source_copy_text,"%i file(s) and %i directories",selected_files,selected_dirs);
		}
	else
		{
			file_name=panels[active_panel].panel_files[panels[active_panel].panel_files_order[panels[active_panel].cursor_file]].name;

			//is it the parent directory?
			if(file_name[0]=='.' && file_name[1]=='.')
				{
					menus[copy_menu_id].opened=0;
					return;
				}

			strcpy(source_copy_text,panels[active_panel].dir_path);

			some_char=panels[active_panel].dir_path[strlen(panels[active_panel].dir_path)-1];
			if(some_char!='\\' && some_char!='/')
				{
#ifdef WINDOWS
					strcat(source_copy_text,"\\");
#else
					strcat(source_copy_text,"/");
#endif
				}
			strcat(source_copy_text,file_name);
		}

	cursor_pos=strlen(dest_copy_text);
	my_TTF_SizeText(font_default, dest_copy_text, &text_w, &text_h);
	cursor_loc=text_w;
}

void pre_open_delete_menu()
{

	int selected_dirs=0;
	int selected_files=0;
	int i;
	char *file_name;
	int text_w,text_h;

	for(i=0;i<panels[active_panel].number_of_files;i++)
	if(panels[active_panel].panel_files[i].selected)
		{
			if(panels[active_panel].panel_files[i].is_dir)
	 		selected_dirs++;
	 		else
	 		selected_files++;
		}

	if(selected_files || selected_dirs)
		{
			if(selected_files && !selected_dirs)
			sprintf(delete_string,"%i files(s)",selected_files);
			else
			if(!selected_files && selected_dirs)
			sprintf(delete_string,"%i directories",selected_dirs);
			else
			sprintf(delete_string,"%i file(s) and %i directories",selected_files,selected_dirs);
		}
	else
		{
			file_name=panels[active_panel].panel_files[panels[active_panel].panel_files_order[panels[active_panel].cursor_file]].name;

			//is it the parent directory?
			if(file_name[0]=='.' && file_name[1]=='.')
				{
					menus[delete_menu_id].opened=0;
					return;
				}

			if(panels[active_panel].panel_files[panels[active_panel].panel_files_order[panels[active_panel].cursor_file]].is_dir)
			sprintf(delete_string,"Directory: %s",file_name);
			else
			sprintf(delete_string,"File: %s",file_name);
		}

}


void draw_main_buttons(SDL_Surface * this_screen)
{
	int i;
	int button_size;
	int button_offset;
	int text_offset;
	int text_width;
	int text_height;

	button_size=window_width/BUTTONS_NO;
	button_size-=BUTTONS_SPACING;

	//draw main bar
	draw_empty_menu(screen, C_MENU_COLOR, 0, window_height-24, window_width-1, window_height,C_MEDIUM_GRAY,C_DARK_GRAY);

	for(i=0;i<BUTTONS_NO;i++)
		{
			button_offset=4+i*(button_size+BUTTONS_SPACING);
			//button frame
			if(!bottom_buttons[i].pressed)
			draw_empty_button(screen, C_MENU_COLOR, button_offset, window_height-21, button_size, 17,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);
			else
			draw_empty_button(screen, C_MENU_COLOR, button_offset, window_height-21, button_size, 17,C_DARK_GRAY,C_WHITE,C_MEDIUM_GRAY);
			//button text
			if(!shift_on)
				{
					my_TTF_SizeText(font_default, bottom_buttons[i].name_normal, &text_width, &text_height);
					text_offset=(button_size-text_width)/2;

					TTF_DrawText(this_screen, font_default,button_offset+text_offset,window_height-19,C_BLACK,bottom_buttons[i].name_normal,300);
				}
			else
				{
					my_TTF_SizeText(font_default, bottom_buttons[i].name_shift, &text_width, &text_height);
					text_offset=(button_size-text_width)/2;

					TTF_DrawText(this_screen, font_default,button_offset+text_offset,window_height-19,C_BLACK,bottom_buttons[i].name_shift,300);
				}
		}



}

int any_menu_open()
{
	if(menus[delete_menu_id].opened)return 1;
	if(menus[copying_menu_id].opened)return 1;
	if(menus[mkdir_menu_id].opened)return 1;
	if(menus[copy_menu_id].opened)return 1;
	if(menus[config_menu_id].opened)return 1;

	return 0;
}

void activate_copy_menu()
{
	if(any_menu_open())return;
	menus[copy_menu_id].opened=1;

	move_instead_of_copy=0;
	strcpy(menus[copy_menu_id].name,"Copy files");
	pre_open_copy_menu();
}

void activate_move_menu()
{
	if(any_menu_open())return;
	menus[copy_menu_id].opened=1;

	move_instead_of_copy=1;
	strcpy(menus[copy_menu_id].name,"Move files");
	pre_open_copy_menu();
}

void activate_mkdir_menu()
{
	if(any_menu_open())return;
	menus[mkdir_menu_id].opened=1;
}

void activate_delete_menu()
{
	if(any_menu_open())return;
	menus[delete_menu_id].opened=1;
	pre_open_delete_menu();
}

int check_main_buttons(int left_b, int right_b, int mouse_x, int mouse_y)
{
	int button_size;
	int cur_button;
	int i;

	if(mouse_y<window_height-24 || mouse_y>window_height-1)return 0;

	//check to see which button (if any) is pressed
	button_size=window_width/BUTTONS_NO;
	cur_button=mouse_x/button_size;

	if(left_b)
		{
			for(i=0;i<BUTTONS_NO;i++)bottom_buttons[i].pressed=0;
			bottom_buttons[cur_button].pressed=1;
		}
	else
		{
			if(bottom_buttons[cur_button].pressed==1)
				{
					bottom_buttons[cur_button].pressed=0;

					if(!shift_on)
						{
							if(bottom_buttons[cur_button].press_func_normal!=NULL)
							bottom_buttons[cur_button].press_func_normal();
						}
					else
						{
							if(bottom_buttons[cur_button].press_func_shift!=NULL)
							bottom_buttons[cur_button].press_func_shift();
						}
				}
		}

}

#define COPYING_CANCEL_X_OFF 180
#define COPYING_CANCEL_Y_OFF 190
#define COPYING_CANCEL_X_LEN 70
#define COPYING_CANCEL_Y_LEN 22

void draw_copying_menu()
{
	char copied_files_str[128];
	char cur_file_status_str[128];
	char tmp_str_1[32];
	char tmp_str_2[32];
	int text_width;
	int text_height;
	int text_x_start;
	int cur_file_percent;
	int progress_bar_len;

	draw_menu_window(screen,menus[copying_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[copying_menu_id].x_1, menus[copying_menu_id].y_1, menus[copying_menu_id].x_2-menus[copying_menu_id].x_1, menus[copying_menu_id].y_2-menus[copying_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);

	draw_description_frame(screen, "", menus[copying_menu_id].x_1+10, menus[copying_menu_id].y_1+30, 400, 150,C_MEDIUM_GRAY ,C_WHITE);

	sprintf(copied_files_str,"Files copied: %i",files_copied);

	if(!this_file_copying_size)cur_file_percent=0;
	else
	cur_file_percent=(this_file_copied_size*100)/this_file_copying_size;

	format_number(this_file_copied_size,tmp_str_1,(decimal_separator) ? '.':',');
	format_number(this_file_copying_size,tmp_str_2,(decimal_separator) ? '.':',');
	sprintf(cur_file_status_str,"%s / %s (%i%%)",tmp_str_1,tmp_str_2,cur_file_percent);


	TTF_DrawText(screen, font_default,menus[copying_menu_id].x_1+20,menus[copying_menu_id].y_1+40,C_BLACK,copied_files_str,315);
	TTF_DrawText_multiple_lines(screen, font_default,menus[copying_menu_id].x_1+20,menus[copying_menu_id].y_1+60,C_BLACK,current_copying_file,350,2);
	draw_empty_menu(screen, C_MENU_COLOR, menus[copying_menu_id].x_1+20, menus[copying_menu_id].y_1+100, 380, 12, C_MEDIUM_GRAY, C_WHITE);

	progress_bar_len=((float)380/(float)100)*cur_file_percent;
	draw_line(screen, menus[copying_menu_id].x_1+20, menus[copying_menu_id].y_1+101, 11, progress_bar_len, C_MENU_TITLE);

	my_TTF_SizeText(font_bold, cur_file_status_str, &text_width, &text_height);
	text_x_start=((menus[copying_menu_id].x_2-menus[copying_menu_id].x_1)-text_width)/2;

	TTF_DrawText(screen, font_default,menus[copying_menu_id].x_1+text_x_start,menus[copying_menu_id].y_1+115,C_BLACK,cur_file_status_str,315);


	if(!files_to_be_copied_size)cur_file_percent=0;
	else
	cur_file_percent=(files_copied_size*100)/files_to_be_copied_size;

	format_number(files_copied_size,tmp_str_1,(decimal_separator) ? '.':',');
	format_number(files_to_be_copied_size,tmp_str_2,(decimal_separator) ? '.':',');
	sprintf(cur_file_status_str,"%s / %s (%i%%)",tmp_str_1,tmp_str_2,cur_file_percent);

	draw_empty_menu(screen, C_MENU_COLOR, menus[copying_menu_id].x_1+20, menus[copying_menu_id].y_1+135, 380, 12, C_MEDIUM_GRAY, C_WHITE);

	progress_bar_len=((float)380/(float)100)*cur_file_percent;
	if(files_to_be_copied_size)draw_line(screen, menus[copying_menu_id].x_1+20, menus[copying_menu_id].y_1+136, 11, progress_bar_len, C_MENU_TITLE);

	my_TTF_SizeText(font_bold, cur_file_status_str, &text_width, &text_height);
	text_x_start=((menus[copying_menu_id].x_2-menus[copying_menu_id].x_1)-text_width)/2;

	if(files_to_be_copied_size)TTF_DrawText(screen, font_default,menus[copying_menu_id].x_1+text_x_start,menus[copying_menu_id].y_1+150,C_BLACK,cur_file_status_str,315);



	if(!copying_cancel_button)draw_frame_button(screen, menus[copying_menu_id].x_1+COPYING_CANCEL_X_OFF, menus[copying_menu_id].y_1+COPYING_CANCEL_Y_OFF, COPYING_CANCEL_X_LEN, COPYING_CANCEL_Y_LEN, C_WHITE, C_DARK_GRAY, C_MEDIUM_GRAY);
	else draw_frame_button(screen, menus[copying_menu_id].x_1+COPYING_CANCEL_X_OFF, menus[copying_menu_id].y_1+COPYING_CANCEL_Y_OFF, COPYING_CANCEL_X_LEN, COPYING_CANCEL_Y_LEN, C_DARK_GRAY,C_WHITE,C_MEDIUM_GRAY);
	TTF_DrawText(screen, font_default,menus[copying_menu_id].x_1+COPYING_CANCEL_X_OFF+15,menus[copying_menu_id].y_1+COPYING_CANCEL_Y_OFF+5,C_BLACK,"Cancel",315);

}

void click_copying_cancel()
{
	cancel_copy=1;
	menus[copying_menu_id].opened=0;
}

void copying_menu_keypresses(Uint8 ascii)
{
	Uint8 * key;
	key=SDL_GetKeyState(NULL);

	if(key[SDLK_ESCAPE])
		{
			click_copying_cancel();
		}
}

void click_copying_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	//Cancel button?
	if(mouse_x>=menus[copying_menu_id].x_1+COPYING_CANCEL_X_OFF && mouse_x<=menus[copying_menu_id].x_1+COPYING_CANCEL_X_OFF+COPYING_CANCEL_X_LEN && mouse_y>=menus[copying_menu_id].y_1+COPYING_CANCEL_Y_OFF &&
	mouse_y<=menus[copying_menu_id].y_1+COPYING_CANCEL_Y_OFF+COPYING_CANCEL_Y_LEN)
		{
			if(copying_cancel_button && !left_b)//depressing left button
				{
					click_copying_cancel();
					copying_cancel_button=0;
					return;
				}

			if(left_b)
			copying_cancel_button=1;
		}
		else
		copying_cancel_button=0;
}

#define OVERWRITE_YES_X_OFF 40
#define OVERWRITE_YES_Y_OFF 150
#define OVERWRITE_YES_X_LEN 70
#define OVERWRITE_YES_Y_LEN 22

#define OVERWRITE_NO_X_OFF OVERWRITE_YES_X_OFF+OVERWRITE_YES_X_LEN+6
#define OVERWRITE_NO_Y_OFF 150
#define OVERWRITE_NO_X_LEN 70
#define OVERWRITE_NO_Y_LEN 22

#define OVERWRITE_ALL_X_OFF OVERWRITE_NO_X_OFF+OVERWRITE_NO_X_LEN+6
#define OVERWRITE_ALL_Y_OFF 150
#define OVERWRITE_ALL_X_LEN 70
#define OVERWRITE_ALL_Y_LEN 22

#define OVERWRITE_NONE_X_OFF OVERWRITE_ALL_X_OFF+OVERWRITE_ALL_X_LEN+6
#define OVERWRITE_NONE_Y_OFF 150
#define OVERWRITE_NONE_X_LEN 70
#define OVERWRITE_NONE_Y_LEN 22

#define OVERWRITE_CANCEL_X_OFF OVERWRITE_NONE_X_OFF+OVERWRITE_NONE_X_LEN+6
#define OVERWRITE_CANCEL_Y_OFF 150
#define OVERWRITE_CANCEL_X_LEN 70
#define OVERWRITE_CANCEL_Y_LEN 22

void draw_overwrite_menu()
{
	char str[2048];
	draw_menu_window(screen,menus[overwrite_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[overwrite_menu_id].x_1, menus[overwrite_menu_id].y_1, menus[overwrite_menu_id].x_2-menus[overwrite_menu_id].x_1, menus[overwrite_menu_id].y_2-menus[overwrite_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);


	//draw the src text
	sprintf(str,"Source file: %s",current_copying_file);
	TTF_DrawText_multiple_lines(screen, font_default,menus[overwrite_menu_id].x_1+10,menus[overwrite_menu_id].y_1+25,C_BLACK,str,480,2);

	sprintf(str,"Date: %s",overwrite_source_date);
	TTF_DrawText(screen, font_default,menus[overwrite_menu_id].x_1+10,menus[overwrite_menu_id].y_1+51,C_BLACK,str,480);

	sprintf(str,"Size: %s",overwrite_source_size);
	TTF_DrawText(screen, font_default,menus[overwrite_menu_id].x_1+10,menus[overwrite_menu_id].y_1+67,C_BLACK,str,480);

	//draw dest text
	sprintf(str,"Destination file: %s",current_copying_file_dest);
	TTF_DrawText_multiple_lines(screen, font_default,menus[overwrite_menu_id].x_1+10,menus[overwrite_menu_id].y_1+90,C_BLACK,str,480,2);

	sprintf(str,"Date: %s",overwrite_dest_date);
	TTF_DrawText(screen, font_default,menus[overwrite_menu_id].x_1+10,menus[overwrite_menu_id].y_1+116,C_BLACK,str,480);

	sprintf(str,"Size: %s",overwrite_dest_size);
	TTF_DrawText(screen, font_default,menus[overwrite_menu_id].x_1+10,menus[overwrite_menu_id].y_1+132,C_BLACK,str,480);




	//draw the buttons
	draw_button(screen, "Yes", menus[overwrite_menu_id].x_1+OVERWRITE_YES_X_OFF, menus[overwrite_menu_id].y_1+OVERWRITE_YES_Y_OFF, OVERWRITE_YES_X_LEN, OVERWRITE_YES_Y_LEN, overwrite_yes_button, (overwrite_selected_button==OVERWRITE_YES) ? 1:0);
	draw_button(screen, "No", menus[overwrite_menu_id].x_1+OVERWRITE_NO_X_OFF, menus[overwrite_menu_id].y_1+OVERWRITE_NO_Y_OFF, OVERWRITE_NO_X_LEN, OVERWRITE_NO_Y_LEN, overwrite_no_button, (overwrite_selected_button==OVERWRITE_NO) ? 1:0);
	draw_button(screen, "All", menus[overwrite_menu_id].x_1+OVERWRITE_ALL_X_OFF, menus[overwrite_menu_id].y_1+OVERWRITE_ALL_Y_OFF, OVERWRITE_ALL_X_LEN, OVERWRITE_ALL_Y_LEN, overwrite_all_button, (overwrite_selected_button==OVERWRITE_ALL) ? 1:0);
	draw_button(screen, "None", menus[overwrite_menu_id].x_1+OVERWRITE_NONE_X_OFF, menus[overwrite_menu_id].y_1+OVERWRITE_NONE_Y_OFF, OVERWRITE_NONE_X_LEN, OVERWRITE_NONE_Y_LEN, overwrite_none_button, (overwrite_selected_button==OVERWRITE_NONE) ? 1:0);
	draw_button(screen, "Cancel", menus[overwrite_menu_id].x_1+OVERWRITE_CANCEL_X_OFF, menus[overwrite_menu_id].y_1+OVERWRITE_CANCEL_Y_OFF, OVERWRITE_CANCEL_X_LEN, OVERWRITE_CANCEL_Y_LEN, overwrite_cancel_button, (overwrite_selected_button==OVERWRITE_CANCEL) ? 1:0);

}

void click_overwrite_yes()
{
	overwrite_decision=OVERWRITE_FILE_OVERWRITE_THIS;
	menus[overwrite_menu_id].opened=0;
}

void click_overwrite_no()
{
	overwrite_decision=OVERWRITE_FILE_SKIP_THIS;
	menus[overwrite_menu_id].opened=0;
}

void click_overwrite_all()
{
	overwrite_decision=OVERWRITE_FILE_OVERWRITE_ALL;
	menus[overwrite_menu_id].opened=0;
}

void click_overwrite_none()
{
	overwrite_decision=OVERWRITE_FILE_SKIP_ALL;
	menus[overwrite_menu_id].opened=0;
}

void click_overwrite_cancel()
{
	overwrite_decision=OVERWRITE_FILE_CANCEL;
	menus[overwrite_menu_id].opened=0;
}

void click_overwrite_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	//Yes button?
	if(mouse_x>=menus[overwrite_menu_id].x_1+OVERWRITE_YES_X_OFF && mouse_x<=menus[overwrite_menu_id].x_1+OVERWRITE_YES_X_OFF+OVERWRITE_YES_X_LEN && mouse_y>=menus[overwrite_menu_id].y_1+OVERWRITE_YES_Y_OFF &&
	mouse_y<=menus[overwrite_menu_id].y_1+OVERWRITE_YES_Y_OFF+OVERWRITE_YES_Y_LEN)
		{
			if(overwrite_yes_button && !left_b)//depressing left button
				{
					click_overwrite_yes();
					overwrite_yes_button=0;
					return;
				}

			if(left_b)
			overwrite_yes_button=1;
		}
		else
		overwrite_yes_button=0;

	//No button?
	if(mouse_x>=menus[overwrite_menu_id].x_1+OVERWRITE_NO_X_OFF && mouse_x<=menus[overwrite_menu_id].x_1+OVERWRITE_NO_X_OFF+OVERWRITE_NO_X_LEN && mouse_y>=menus[overwrite_menu_id].y_1+OVERWRITE_NO_Y_OFF &&
	mouse_y<=menus[overwrite_menu_id].y_1+OVERWRITE_NO_Y_OFF+OVERWRITE_NO_Y_LEN)
		{
			if(overwrite_no_button && !left_b)//depressing left button
				{
					click_overwrite_no();
					overwrite_no_button=0;
					return;
				}

			if(left_b)
			overwrite_no_button=1;
		}
		else
		overwrite_no_button=0;

	//All button?
	if(mouse_x>=menus[overwrite_menu_id].x_1+OVERWRITE_ALL_X_OFF && mouse_x<=menus[overwrite_menu_id].x_1+OVERWRITE_ALL_X_OFF+OVERWRITE_ALL_X_LEN && mouse_y>=menus[overwrite_menu_id].y_1+OVERWRITE_ALL_Y_OFF &&
	mouse_y<=menus[overwrite_menu_id].y_1+OVERWRITE_ALL_Y_OFF+OVERWRITE_ALL_Y_LEN)
		{
			if(overwrite_all_button && !left_b)//depressing left button
				{
					click_overwrite_all();
					overwrite_all_button=0;
					return;
				}

			if(left_b)
			overwrite_all_button=1;
		}
		else
		overwrite_all_button=0;

	//none button?
	if(mouse_x>=menus[overwrite_menu_id].x_1+OVERWRITE_NONE_X_OFF && mouse_x<=menus[overwrite_menu_id].x_1+OVERWRITE_NONE_X_OFF+OVERWRITE_NONE_X_LEN && mouse_y>=menus[overwrite_menu_id].y_1+OVERWRITE_NONE_Y_OFF &&
	mouse_y<=menus[overwrite_menu_id].y_1+OVERWRITE_NONE_Y_OFF+OVERWRITE_NONE_Y_LEN)
		{
			if(overwrite_none_button && !left_b)//depressing left button
				{
					click_overwrite_none();
					overwrite_none_button=0;
					return;
				}

			if(left_b)
			overwrite_none_button=1;
		}
		else
		overwrite_none_button=0;

	//Cancel button?
	if(mouse_x>=menus[overwrite_menu_id].x_1+OVERWRITE_CANCEL_X_OFF && mouse_x<=menus[overwrite_menu_id].x_1+OVERWRITE_CANCEL_X_OFF+OVERWRITE_CANCEL_X_LEN && mouse_y>=menus[overwrite_menu_id].y_1+OVERWRITE_CANCEL_Y_OFF &&
	mouse_y<=menus[overwrite_menu_id].y_1+OVERWRITE_CANCEL_Y_OFF+OVERWRITE_CANCEL_Y_LEN)
		{
			if(overwrite_cancel_button && !left_b)//depressing left button
				{
					click_overwrite_cancel();
					overwrite_cancel_button=0;
					return;
				}

			if(left_b)
			overwrite_cancel_button=1;
		}
		else
		overwrite_cancel_button=0;
}

void overwrite_menu_keypresses(Uint8 ascii)
{
	Uint8 * key;
	key=SDL_GetKeyState(NULL);

	if(key[SDLK_RIGHT])
		{
			overwrite_selected_button++;
			if(overwrite_selected_button>OVERWRITE_CANCEL)overwrite_selected_button=0;
			return;
		}

	if(key[SDLK_LEFT])
		{
			overwrite_selected_button--;
			if(overwrite_selected_button<0)overwrite_selected_button=OVERWRITE_CANCEL;
			return;
		}

	if(key[SDLK_RETURN])
		{
			if(overwrite_selected_button==OVERWRITE_YES)
			click_overwrite_yes();
			else
			if(overwrite_selected_button==OVERWRITE_NO)
			click_overwrite_no();
			else
			if(overwrite_selected_button==OVERWRITE_ALL)
			click_overwrite_all();
			else
			if(overwrite_selected_button==OVERWRITE_NONE)
			click_overwrite_none();
			else
			if(overwrite_selected_button==OVERWRITE_CANCEL)
			click_overwrite_cancel();

			return;
		}

	if(key[SDLK_ESCAPE])
		{
			click_overwrite_cancel();
		}

	keyboard_write_string(dest_copy_text,ascii, 1024);
}

#define CONFIGURE_OK_X_OFF 180
#define CONFIGURE_OK_Y_OFF 270
#define CONFIGURE_OK_X_LEN 70
#define CONFIGURE_OK_Y_LEN 22

#define CONFIGURE_CANCEL_X_OFF CONFIGURE_OK_X_OFF+CONFIGURE_OK_X_LEN+10
#define CONFIGURE_CANCEL_Y_OFF 270
#define CONFIGURE_CANCEL_X_LEN 70
#define CONFIGURE_CANCEL_Y_LEN 22

#define CONFIGURE_SHOW_HIDDEN_X_OFF 12
#define CONFIGURE_SHOW_HIDDEN_Y_OFF 50
#define CONFIGURE_SHOW_HIDDEN_X_LEN 11
#define CONFIGURE_SHOW_HIDDEN_Y_LEN 11

#define CONFIGURE_DATE_0_X_OFF 12
#define CONFIGURE_DATE_0_Y_OFF CONFIGURE_SHOW_HIDDEN_Y_OFF+34
#define CONFIGURE_DATE_0_X_LEN 11
#define CONFIGURE_DATE_0_Y_LEN 11

#define CONFIGURE_DATE_1_X_OFF 12
#define CONFIGURE_DATE_1_Y_OFF CONFIGURE_DATE_0_Y_OFF+17
#define CONFIGURE_DATE_1_X_LEN 11
#define CONFIGURE_DATE_1_Y_LEN 11

#define CONFIGURE_DATE_2_X_OFF 12
#define CONFIGURE_DATE_2_Y_OFF CONFIGURE_DATE_1_Y_OFF+17
#define CONFIGURE_DATE_2_X_LEN 11
#define CONFIGURE_DATE_2_Y_LEN 11

#define CONFIGURE_DATE_3_X_OFF 12
#define CONFIGURE_DATE_3_Y_OFF CONFIGURE_DATE_2_Y_OFF+17
#define CONFIGURE_DATE_3_X_LEN 11
#define CONFIGURE_DATE_3_Y_LEN 11

#define CONFIGURE_PANEL_1_X_OFF 300
#define CONFIGURE_PANEL_1_Y_OFF CONFIGURE_SHOW_HIDDEN_Y_OFF
#define CONFIGURE_PANEL_1_X_LEN 14
#define CONFIGURE_PANEL_1_Y_LEN 14

#define CONFIGURE_PANEL_2_X_OFF CONFIGURE_PANEL_1_X_OFF+40
#define CONFIGURE_PANEL_2_Y_OFF CONFIGURE_SHOW_HIDDEN_Y_OFF
#define CONFIGURE_PANEL_2_X_LEN 14
#define CONFIGURE_PANEL_2_Y_LEN 14

#define CONFIGURE_KB_0_X_OFF 182
#define CONFIGURE_KB_0_Y_OFF CONFIGURE_PANEL_1_Y_OFF+34
#define CONFIGURE_KB_0_X_LEN 11
#define CONFIGURE_KB_0_Y_LEN 11

#define CONFIGURE_KB_1_X_OFF 182
#define CONFIGURE_KB_1_Y_OFF CONFIGURE_KB_0_Y_OFF+17
#define CONFIGURE_KB_1_X_LEN 11
#define CONFIGURE_KB_1_Y_LEN 11

#define CONFIGURE_SEPARATOR_0_X_OFF 182
#define CONFIGURE_SEPARATOR_0_Y_OFF CONFIGURE_KB_1_Y_OFF+34
#define CONFIGURE_SEPARATOR_0_X_LEN 11
#define CONFIGURE_SEPARATOR_0_Y_LEN 11

#define CONFIGURE_SEPARATOR_1_X_OFF 182
#define CONFIGURE_SEPARATOR_1_Y_OFF CONFIGURE_SEPARATOR_0_Y_OFF+17
#define CONFIGURE_SEPARATOR_1_X_LEN 11
#define CONFIGURE_SEPARATOR_1_Y_LEN 11

#define CONFIGURE_EDITOR_TEXT_X_OFF 92
#define CONFIGURE_EDITOR_TEXT_Y_OFF 180
#define CONFIGURE_EDITOR_TEXT_X_LEN 360
#define CONFIGURE_EDITOR_TEXT_Y_LEN 20

#define CONFIGURE_VIEWER_TEXT_X_OFF 92
#define CONFIGURE_VIEWER_TEXT_Y_OFF 210
#define CONFIGURE_VIEWER_TEXT_X_LEN 360
#define CONFIGURE_VIEWER_TEXT_Y_LEN 20

#define CONFIGURE_HEX_VIEWER_TEXT_X_OFF 92
#define CONFIGURE_HEX_VIEWER_TEXT_Y_OFF 240
#define CONFIGURE_HEX_VIEWER_TEXT_X_LEN 360
#define CONFIGURE_HEX_VIEWER_TEXT_Y_LEN 20

char configure_show_hidden_files;
char configure_collums_per_panel;
char configure_kb_size;
char configure_decimal_separator;
char configure_date_format;

char configure_default_editor[256];
char configure_default_viewer[256];
char configure_hex_viewer[256];

void activate_config_menu()
{
	if(any_menu_open())return;

	configure_show_hidden_files=show_hidden;
	configure_collums_per_panel=collums_per_panel;
	configure_date_format=date_format;
	configure_kb_size=kb_size;
	configure_decimal_separator=decimal_separator;

	strcpy(configure_default_editor,default_editor);
	strcpy(configure_default_viewer,default_viewer);
	strcpy(configure_hex_viewer,hex_viewer);

	menus[config_menu_id].opened=1;
}

void draw_config_menu()
{
	char str[200];
	draw_menu_window(screen,menus[config_menu_id].name,C_MENU_COLOR,C_MENU_TITLE, menus[config_menu_id].x_1, menus[config_menu_id].y_1, menus[config_menu_id].x_2-menus[config_menu_id].x_1, menus[config_menu_id].y_2-menus[config_menu_id].y_1,C_WHITE,C_DARK_GRAY,C_MEDIUM_GRAY);

	//Show hidden files
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_SHOW_HIDDEN_X_OFF, menus[config_menu_id].y_1+CONFIGURE_SHOW_HIDDEN_Y_OFF, CONFIGURE_SHOW_HIDDEN_X_LEN, CONFIGURE_SHOW_HIDDEN_Y_LEN, C_BLACK, C_BLACK);
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_SHOW_HIDDEN_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_SHOW_HIDDEN_Y_OFF+1, CONFIGURE_SHOW_HIDDEN_Y_LEN-1, CONFIGURE_SHOW_HIDDEN_X_LEN-1, C_WHITE);
	if(configure_show_hidden_files)
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_SHOW_HIDDEN_X_OFF+2, menus[config_menu_id].y_1+CONFIGURE_SHOW_HIDDEN_Y_OFF+2, CONFIGURE_SHOW_HIDDEN_Y_LEN-3, CONFIGURE_SHOW_HIDDEN_X_LEN-3, C_BLACK);
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+30,menus[config_menu_id].y_1+CONFIGURE_SHOW_HIDDEN_Y_OFF+1,C_BLACK,"Show hidden files",200);

	//Date format
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+30,menus[config_menu_id].y_1+CONFIGURE_SHOW_HIDDEN_Y_OFF+1+17,C_BLACK,"Date format:",200);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+30,menus[config_menu_id].y_1+CONFIGURE_DATE_0_Y_OFF,C_BLACK,"dd:mmm:yyyy hh:mm:ss",200);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_0_X_OFF, menus[config_menu_id].y_1+CONFIGURE_DATE_0_Y_OFF, CONFIGURE_DATE_0_X_LEN, CONFIGURE_DATE_0_Y_LEN, C_BLACK, C_BLACK);
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_0_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_DATE_0_Y_OFF+1, CONFIGURE_DATE_0_Y_LEN-1, CONFIGURE_DATE_0_X_LEN-1, C_WHITE);
	if(configure_date_format==0)
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_0_X_OFF+2, menus[config_menu_id].y_1+CONFIGURE_DATE_0_Y_OFF+2, CONFIGURE_DATE_0_Y_LEN-3, CONFIGURE_DATE_0_X_LEN-3, C_BLACK);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+30,menus[config_menu_id].y_1+CONFIGURE_DATE_1_Y_OFF,C_BLACK,"mmm:dd:yyyy hh:mm:ss",200);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_1_X_OFF, menus[config_menu_id].y_1+CONFIGURE_DATE_1_Y_OFF, CONFIGURE_DATE_1_X_LEN, CONFIGURE_DATE_1_Y_LEN, C_BLACK, C_BLACK);
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_1_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_DATE_1_Y_OFF+1, CONFIGURE_DATE_1_Y_LEN-1, CONFIGURE_DATE_1_X_LEN-1, C_WHITE);
	if(configure_date_format==1)
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_1_X_OFF+2, menus[config_menu_id].y_1+CONFIGURE_DATE_1_Y_OFF+2, CONFIGURE_DATE_1_Y_LEN-3, CONFIGURE_DATE_1_X_LEN-3, C_BLACK);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+30,menus[config_menu_id].y_1+CONFIGURE_DATE_2_Y_OFF,C_BLACK,"hh:mm:ss dd:mmm:yyyy",200);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_2_X_OFF, menus[config_menu_id].y_1+CONFIGURE_DATE_2_Y_OFF, CONFIGURE_DATE_2_X_LEN, CONFIGURE_DATE_2_Y_LEN, C_BLACK, C_BLACK);
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_2_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_DATE_2_Y_OFF+1, CONFIGURE_DATE_2_Y_LEN-1, CONFIGURE_DATE_2_X_LEN-1, C_WHITE);
	if(configure_date_format==2)
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_2_X_OFF+2, menus[config_menu_id].y_1+CONFIGURE_DATE_2_Y_OFF+2, CONFIGURE_DATE_2_Y_LEN-3, CONFIGURE_DATE_2_X_LEN-3, C_BLACK);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+30,menus[config_menu_id].y_1+CONFIGURE_DATE_3_Y_OFF,C_BLACK,"hh:mm:ss mmm:dd:yyyy",200);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_3_X_OFF, menus[config_menu_id].y_1+CONFIGURE_DATE_3_Y_OFF, CONFIGURE_DATE_3_X_LEN, CONFIGURE_DATE_3_Y_LEN, C_BLACK, C_BLACK);
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_3_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_DATE_3_Y_OFF+1, CONFIGURE_DATE_3_Y_LEN-1, CONFIGURE_DATE_3_X_LEN-1, C_WHITE);
	if(configure_date_format==3)
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_DATE_3_X_OFF+2, menus[config_menu_id].y_1+CONFIGURE_DATE_3_Y_OFF+2, CONFIGURE_DATE_3_Y_LEN-3, CONFIGURE_DATE_3_X_LEN-3, C_BLACK);

	//number of collumns
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+200,menus[config_menu_id].y_1+CONFIGURE_PANEL_1_Y_OFF,C_BLACK,"Collums per panel:",200);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_PANEL_1_X_OFF, menus[config_menu_id].y_1+CONFIGURE_PANEL_1_Y_OFF, CONFIGURE_PANEL_1_X_LEN, CONFIGURE_PANEL_1_Y_LEN, C_BLACK, C_BLACK);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_PANEL_2_X_OFF, menus[config_menu_id].y_1+CONFIGURE_PANEL_2_Y_OFF, CONFIGURE_PANEL_2_X_LEN, CONFIGURE_PANEL_2_Y_LEN, C_BLACK, C_BLACK);
	draw_empty_menu(screen, C_WHITE, menus[config_menu_id].x_1+CONFIGURE_PANEL_1_X_OFF+CONFIGURE_PANEL_1_X_LEN+5, menus[config_menu_id].y_1+CONFIGURE_PANEL_1_Y_OFF-1, 16, 16, C_MEDIUM_GRAY, C_WHITE);
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_PANEL_1_X_OFF+3,menus[config_menu_id].y_1+CONFIGURE_PANEL_1_Y_OFF+1,C_BLACK,"<",200);
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_PANEL_2_X_OFF+3,menus[config_menu_id].y_1+CONFIGURE_PANEL_2_Y_OFF+1,C_BLACK,">",200);
	sprintf(str,"%i",configure_collums_per_panel);
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_PANEL_1_X_OFF+CONFIGURE_PANEL_1_X_LEN+10,menus[config_menu_id].y_1+CONFIGURE_PANEL_1_Y_OFF+2,C_BLACK,str,200);

	//KB size
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+200,menus[config_menu_id].y_1+CONFIGURE_PANEL_1_Y_OFF+1+17,C_BLACK,"KB size:",200);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+200,menus[config_menu_id].y_1+CONFIGURE_KB_0_Y_OFF,C_BLACK,"1024",200);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_KB_0_X_OFF, menus[config_menu_id].y_1+CONFIGURE_KB_0_Y_OFF, CONFIGURE_KB_0_X_LEN, CONFIGURE_KB_0_Y_LEN, C_BLACK, C_BLACK);
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_KB_0_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_KB_0_Y_OFF+1, CONFIGURE_KB_0_Y_LEN-1, CONFIGURE_KB_0_X_LEN-1, C_WHITE);
	if(configure_kb_size==0)
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_KB_0_X_OFF+2, menus[config_menu_id].y_1+CONFIGURE_KB_0_Y_OFF+2, CONFIGURE_KB_0_Y_LEN-3, CONFIGURE_KB_0_X_LEN-3, C_BLACK);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+200,menus[config_menu_id].y_1+CONFIGURE_KB_1_Y_OFF,C_BLACK,"1000",200);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_KB_1_X_OFF, menus[config_menu_id].y_1+CONFIGURE_KB_1_Y_OFF, CONFIGURE_KB_1_X_LEN, CONFIGURE_KB_1_Y_LEN, C_BLACK, C_BLACK);
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_KB_1_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_KB_1_Y_OFF+1, CONFIGURE_KB_1_Y_LEN-1, CONFIGURE_KB_1_X_LEN-1, C_WHITE);
	if(configure_kb_size==1)
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_KB_1_X_OFF+2, menus[config_menu_id].y_1+CONFIGURE_KB_1_Y_OFF+2, CONFIGURE_KB_1_Y_LEN-3, CONFIGURE_KB_1_X_LEN-3, C_BLACK);

	//separator
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+200,menus[config_menu_id].y_1+CONFIGURE_KB_1_Y_OFF+1+17,C_BLACK,"Decimal separator:",200);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+200,menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_0_Y_OFF,C_BLACK,"1,000,000",200);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_0_X_OFF, menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_0_Y_OFF, CONFIGURE_SEPARATOR_0_X_LEN, CONFIGURE_SEPARATOR_0_Y_LEN, C_BLACK, C_BLACK);
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_0_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_0_Y_OFF+1, CONFIGURE_SEPARATOR_0_Y_LEN-1, CONFIGURE_SEPARATOR_0_X_LEN-1, C_WHITE);
	if(configure_decimal_separator==0)
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_0_X_OFF+2, menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_0_Y_OFF+2, CONFIGURE_SEPARATOR_0_Y_LEN-3, CONFIGURE_SEPARATOR_0_X_LEN-3, C_BLACK);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+200,menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_1_Y_OFF,C_BLACK,"1.000.000",200);
	draw_frame(screen, menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_1_X_OFF, menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_1_Y_OFF, CONFIGURE_SEPARATOR_1_X_LEN, CONFIGURE_SEPARATOR_1_Y_LEN, C_BLACK, C_BLACK);
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_1_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_1_Y_OFF+1, CONFIGURE_SEPARATOR_1_Y_LEN-1, CONFIGURE_SEPARATOR_1_X_LEN-1, C_WHITE);
	if(configure_decimal_separator==1)
	draw_line(screen, menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_1_X_OFF+2, menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_1_Y_OFF+2, CONFIGURE_SEPARATOR_1_Y_LEN-3, CONFIGURE_SEPARATOR_1_X_LEN-3, C_BLACK);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_EDITOR_TEXT_X_OFF-80,menus[config_menu_id].y_1+CONFIGURE_EDITOR_TEXT_Y_OFF+5,C_BLACK,"Default editor:",315);
	draw_empty_menu(screen, C_WHITE, menus[config_menu_id].x_1+CONFIGURE_EDITOR_TEXT_X_OFF, menus[config_menu_id].y_1+CONFIGURE_EDITOR_TEXT_Y_OFF, CONFIGURE_EDITOR_TEXT_X_LEN, CONFIGURE_EDITOR_TEXT_Y_LEN, C_MEDIUM_GRAY, C_WHITE);
	draw_empty_menu(screen, C_WHITE, menus[config_menu_id].x_1+CONFIGURE_EDITOR_TEXT_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_EDITOR_TEXT_Y_OFF+1, CONFIGURE_EDITOR_TEXT_X_LEN-2, CONFIGURE_EDITOR_TEXT_Y_LEN-2, C_DARK_GRAY, C_LIGHT_GRAY);
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_EDITOR_TEXT_X_OFF+3,menus[config_menu_id].y_1+CONFIGURE_EDITOR_TEXT_Y_OFF+5,C_BLACK,configure_default_editor,CONFIGURE_EDITOR_TEXT_X_LEN-5);
	if(config_selected_button==CONFIGURE_DEFAULT_EDITOR)TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_EDITOR_TEXT_X_OFF+3+cursor_loc,menus[config_menu_id].y_1+CONFIGURE_EDITOR_TEXT_Y_OFF+4,C_BLACK,"|",10);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_VIEWER_TEXT_X_OFF-80,menus[config_menu_id].y_1+CONFIGURE_VIEWER_TEXT_Y_OFF+5,C_BLACK,"Default viewer:",315);
	draw_empty_menu(screen, C_WHITE, menus[config_menu_id].x_1+CONFIGURE_VIEWER_TEXT_X_OFF, menus[config_menu_id].y_1+CONFIGURE_VIEWER_TEXT_Y_OFF, CONFIGURE_VIEWER_TEXT_X_LEN, CONFIGURE_VIEWER_TEXT_Y_LEN, C_MEDIUM_GRAY, C_WHITE);
	draw_empty_menu(screen, C_WHITE, menus[config_menu_id].x_1+CONFIGURE_VIEWER_TEXT_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_VIEWER_TEXT_Y_OFF+1, CONFIGURE_VIEWER_TEXT_X_LEN-2, CONFIGURE_VIEWER_TEXT_Y_LEN-2, C_DARK_GRAY, C_LIGHT_GRAY);
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_VIEWER_TEXT_X_OFF+3,menus[config_menu_id].y_1+CONFIGURE_VIEWER_TEXT_Y_OFF+5,C_BLACK,configure_default_viewer,CONFIGURE_VIEWER_TEXT_X_LEN-5);
	if(config_selected_button==CONFIGURE_DEFAULT_VIEWER)TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_VIEWER_TEXT_X_OFF+3+cursor_loc,menus[config_menu_id].y_1+CONFIGURE_VIEWER_TEXT_Y_OFF+4,C_BLACK,"|",10);

	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_HEX_VIEWER_TEXT_X_OFF-80,menus[config_menu_id].y_1+CONFIGURE_HEX_VIEWER_TEXT_Y_OFF+5,C_BLACK,"Hex_viewer:",315);
	draw_empty_menu(screen, C_WHITE, menus[config_menu_id].x_1+CONFIGURE_HEX_VIEWER_TEXT_X_OFF, menus[config_menu_id].y_1+CONFIGURE_HEX_VIEWER_TEXT_Y_OFF, CONFIGURE_HEX_VIEWER_TEXT_X_LEN, CONFIGURE_HEX_VIEWER_TEXT_Y_LEN, C_MEDIUM_GRAY, C_WHITE);
	draw_empty_menu(screen, C_WHITE, menus[config_menu_id].x_1+CONFIGURE_HEX_VIEWER_TEXT_X_OFF+1, menus[config_menu_id].y_1+CONFIGURE_HEX_VIEWER_TEXT_Y_OFF+1, CONFIGURE_HEX_VIEWER_TEXT_X_LEN-2, CONFIGURE_HEX_VIEWER_TEXT_Y_LEN-2, C_DARK_GRAY, C_LIGHT_GRAY);
	TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_HEX_VIEWER_TEXT_X_OFF+3,menus[config_menu_id].y_1+CONFIGURE_HEX_VIEWER_TEXT_Y_OFF+5,C_BLACK,configure_hex_viewer,CONFIGURE_HEX_VIEWER_TEXT_X_LEN-5);
	if(config_selected_button==CONFIGURE_HEX_VIEWER)TTF_DrawText(screen, font_default,menus[config_menu_id].x_1+CONFIGURE_HEX_VIEWER_TEXT_X_OFF+3+cursor_loc,menus[config_menu_id].y_1+CONFIGURE_HEX_VIEWER_TEXT_Y_OFF+4,C_BLACK,"|",10);

	draw_button(screen, "Ok", menus[config_menu_id].x_1+CONFIGURE_OK_X_OFF, menus[config_menu_id].y_1+CONFIGURE_OK_Y_OFF, CONFIGURE_OK_X_LEN, CONFIGURE_OK_Y_LEN, config_ok_button, (config_selected_button==CONFIGURE_OK) ? 1:0);
	draw_button(screen, "Cancel", menus[config_menu_id].x_1+CONFIGURE_CANCEL_X_OFF, menus[config_menu_id].y_1+CONFIGURE_CANCEL_Y_OFF, CONFIGURE_CANCEL_X_LEN, CONFIGURE_CANCEL_Y_LEN, configure_cancel_button, (config_selected_button==CONFIGURE_CANCEL) ? 1:0);

}

void click_config_ok()
{
	menus[config_menu_id].opened=0;
	collums_per_panel=configure_collums_per_panel;
	kb_size=configure_kb_size;
	decimal_separator=configure_decimal_separator;
	show_hidden=configure_show_hidden_files;
	date_format=configure_date_format;

	panels[!active_panel].needs_reread=1;
	panels[!active_panel].cursor_file=0;
	panels[active_panel].needs_reread=1;
	panels[active_panel].cursor_file=0;

	strcpy(default_editor,configure_default_editor);
	strcpy(default_viewer,configure_default_viewer);
	strcpy(hex_viewer,configure_hex_viewer);

	cursor_pos=0;
	cursor_loc=0;
}

void click_config_cancel()
{
	menus[config_menu_id].opened=0;
	cursor_pos=0;
	cursor_loc=0;
}

void click_config_menu(int left_b, int right_b, int mouse_x, int mouse_y)
{
	//hidden files
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_SHOW_HIDDEN_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_SHOW_HIDDEN_X_OFF+CONFIGURE_SHOW_HIDDEN_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_SHOW_HIDDEN_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_SHOW_HIDDEN_Y_OFF+CONFIGURE_SHOW_HIDDEN_Y_LEN)
	if(left_b)
		{
			configure_show_hidden_files=!configure_show_hidden_files;
			return;
		}
	//date
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_DATE_0_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_DATE_0_X_OFF+CONFIGURE_DATE_0_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_DATE_0_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_DATE_0_Y_OFF+CONFIGURE_DATE_0_Y_LEN)
	if(left_b)
		{
			configure_date_format=0;
			return;
		}

	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_DATE_1_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_DATE_1_X_OFF+CONFIGURE_DATE_1_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_DATE_1_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_DATE_1_Y_OFF+CONFIGURE_DATE_1_Y_LEN)
	if(left_b)
		{
			configure_date_format=1;
			return;
		}

	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_DATE_2_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_DATE_2_X_OFF+CONFIGURE_DATE_2_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_DATE_2_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_DATE_2_Y_OFF+CONFIGURE_DATE_2_Y_LEN)
	if(left_b)
		{
			configure_date_format=2;
			return;
		}

	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_DATE_3_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_DATE_3_X_OFF+CONFIGURE_DATE_3_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_DATE_3_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_DATE_3_Y_OFF+CONFIGURE_DATE_3_Y_LEN)
	if(left_b)
		{
			configure_date_format=3;
			return;
		}

	//collumns per panel
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_PANEL_1_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_PANEL_1_X_OFF+CONFIGURE_PANEL_1_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_PANEL_1_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_PANEL_1_Y_OFF+CONFIGURE_PANEL_1_Y_LEN)
	if(left_b)
		{
			configure_collums_per_panel--;
			if(configure_collums_per_panel<1)configure_collums_per_panel=1;
			return;
		}

	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_PANEL_2_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_PANEL_2_X_OFF+CONFIGURE_PANEL_2_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_PANEL_2_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_PANEL_2_Y_OFF+CONFIGURE_PANEL_2_Y_LEN)
	if(left_b)
		{
			configure_collums_per_panel++;
			if(configure_collums_per_panel>7)configure_collums_per_panel=7;
			return;
		}

	//KB size
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_KB_0_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_KB_0_X_OFF+CONFIGURE_KB_0_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_KB_0_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_KB_0_Y_OFF+CONFIGURE_KB_0_Y_LEN)
	if(left_b)
		{
			configure_kb_size=0;
			return;
		}

	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_KB_1_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_KB_1_X_OFF+CONFIGURE_KB_1_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_KB_1_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_KB_1_Y_OFF+CONFIGURE_KB_1_Y_LEN)
	if(left_b)
		{
			configure_kb_size=1;
			return;
		}

	//separator
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_0_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_0_X_OFF+CONFIGURE_SEPARATOR_0_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_0_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_0_Y_OFF+CONFIGURE_SEPARATOR_0_Y_LEN)
	if(left_b)
		{
			configure_decimal_separator=0;
			return;
		}

	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_1_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_SEPARATOR_1_X_OFF+CONFIGURE_SEPARATOR_1_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_1_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_SEPARATOR_1_Y_OFF+CONFIGURE_SEPARATOR_1_Y_LEN)
	if(left_b)
		{
			configure_decimal_separator=1;
			return;
		}

	//default editor
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_EDITOR_TEXT_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_EDITOR_TEXT_X_OFF+CONFIGURE_EDITOR_TEXT_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_EDITOR_TEXT_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_EDITOR_TEXT_Y_OFF+CONFIGURE_EDITOR_TEXT_Y_LEN)
	if(left_b)
		{
			move_text_cursor_end(configure_default_editor,256);
			config_selected_button=CONFIGURE_DEFAULT_EDITOR;
			return;
		}

	//default viewer
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_VIEWER_TEXT_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_VIEWER_TEXT_X_OFF+CONFIGURE_VIEWER_TEXT_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_VIEWER_TEXT_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_VIEWER_TEXT_Y_OFF+CONFIGURE_VIEWER_TEXT_Y_LEN)
	if(left_b)
		{
			move_text_cursor_end(configure_default_viewer,256);
			config_selected_button=CONFIGURE_DEFAULT_VIEWER;
			return;
		}

	//default hex_viewer
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_HEX_VIEWER_TEXT_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_HEX_VIEWER_TEXT_X_OFF+CONFIGURE_HEX_VIEWER_TEXT_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_HEX_VIEWER_TEXT_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_HEX_VIEWER_TEXT_Y_OFF+CONFIGURE_HEX_VIEWER_TEXT_Y_LEN)
	if(left_b)
		{
			move_text_cursor_end(configure_hex_viewer,256);
			config_selected_button=CONFIGURE_HEX_VIEWER;
			return;
		}

	//Yes button?
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_OK_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_OK_X_OFF+CONFIGURE_OK_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_OK_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_OK_Y_OFF+CONFIGURE_OK_Y_LEN)
		{
			if(config_ok_button && !left_b)//depressing left button
				{
					click_config_ok();
					config_ok_button=0;
					return;
				}

			if(left_b)
			config_ok_button=1;
		}
	else config_ok_button=0;

	//Cancel button?
	if(mouse_x>=menus[config_menu_id].x_1+CONFIGURE_CANCEL_X_OFF && mouse_x<=menus[config_menu_id].x_1+CONFIGURE_CANCEL_X_OFF+CONFIGURE_CANCEL_X_LEN && mouse_y>=menus[config_menu_id].y_1+CONFIGURE_CANCEL_Y_OFF &&
	mouse_y<=menus[config_menu_id].y_1+CONFIGURE_CANCEL_Y_OFF+CONFIGURE_CANCEL_Y_LEN)
		{
			if(configure_cancel_button && !left_b)//depressing left button
				{
					click_config_cancel();
					configure_cancel_button=0;
					return;
				}

			if(left_b)
			configure_cancel_button=1;
		}
	else configure_cancel_button=0;
}

void config_keypresses(Uint8 ascii)
{
	Uint8 * key;
	key=SDL_GetKeyState(NULL);

	if(key[SDLK_RETURN])
		{
			click_config_ok();
			return;
		}

	if(key[SDLK_ESCAPE])
		{
			click_config_cancel();
		}

	if(config_selected_button==CONFIGURE_DEFAULT_EDITOR)keyboard_write_string(configure_default_editor,ascii, 256);
	if(config_selected_button==CONFIGURE_DEFAULT_VIEWER)keyboard_write_string(configure_default_viewer,ascii, 256);
	if(config_selected_button==CONFIGURE_HEX_VIEWER)keyboard_write_string(configure_hex_viewer,ascii, 256);
}

void draw_main_screen(SDL_Surface * this_screen)
{
	//empty menu and frame
	draw_empty_menu(screen, C_DARK_BLUE, 0, 0, window_width, window_height,C_LIGHT_GRAY,C_LIGHT_GRAY);

	//draw the panels
	draw_panel(screen, collums_per_panel, LEFT_PANEL, (active_panel) ? C_LIGHT_GRAY: C_WHITE);
	draw_panel(screen, collums_per_panel, RIGHT_PANEL, (active_panel) ? C_WHITE:C_LIGHT_GRAY);

	//draw the buttons bar
	draw_main_buttons(screen);
}

