#include "events.h"

int TTF_DrawText(SDL_Surface* screen, TTF_Font* font, int pos_x, int pos_y,int text_color, const char* text, int size)
{
    SDL_Color color = {colors[text_color].r,colors[text_color].g,colors[text_color].b};
    SDL_Surface *text_surface;
    SDL_Rect rectangle = {pos_x,pos_y,0,0};
    SDL_Rect blit_length = {0,0,size,0};

#ifdef WINDOWS
    text_surface = TTF_RenderText_Solid(font, text, color);
#else
	text_surface=TTF_RenderUTF8_Solid(font, text, color);
#endif
    if (text_surface != NULL)
    {
		blit_length.h=text_surface->h;
        SDL_BlitSurface(text_surface, &blit_length, screen, &rectangle);
        SDL_FreeSurface(text_surface);
        return text_surface->w;
    }
    else
    {
        // report error
        return 0;
    }
}

void TTF_DrawText_multiple_lines(SDL_Surface* screen, TTF_Font* font, int pos_x, int pos_y,int text_color, const char* text, int size, int lines)
{
	int chars_per_line=size/6;
	int text_len=strlen(text);
	int total_lines=text_len/chars_per_line;
	int i;
	char str[1024];

	if(text_len%chars_per_line)total_lines++;

	if(total_lines>lines)total_lines=lines;

	for(i=0;i<total_lines;i++)
		{
			strncpy(str,&text[chars_per_line*i],chars_per_line);
			str[chars_per_line]=0;

			TTF_DrawText(screen, font, pos_x, pos_y+13*i,text_color,str, size);
		}

}

int my_TTF_SizeText(TTF_Font *font, const char *text, int *w, int *h)
{
#ifdef WINDOWS
return TTF_SizeText(font, text, w, h);
#else
return TTF_SizeUTF8(font, text, w, h);
#endif
}

int fonts_init()
{
	//init ttf
	if(TTF_Init()==-1)
		{
			char str[256];
		    sprintf(str,"TTF_Init: %s\n", TTF_GetError());
		    log_message(str);
		    return -1;
		}

	//load the default font
	font_default=TTF_OpenFont("./fonts/LiberationSans-Regular.ttf", 11);
	//font_default=TTF_OpenFont("./fonts/luxisr.ttf", 11);
	//font_default=TTF_OpenFont("./fonts/micross.ttf", 11);
	if(!font_default)
		{
			char str[256];
		    sprintf(str,"TTF_OpenFont: %s\n", TTF_GetError());
		    log_message(str);
		    return -1;
		}

	//load the bold font
	font_bold=TTF_OpenFont("./fonts/LiberationSans-Bold.ttf", 11);
	//font_bold=TTF_OpenFont("./fonts/luxisb.ttf", 11);
	if(!font_bold)
		{
			char str[256];
		    sprintf(str,"TTF_OpenFont: %s\n", TTF_GetError());
		    log_message(str);
		    return -1;
		}

	//load the italics font
	font_italic=TTF_OpenFont("./fonts/LiberationSans-Italic.ttf", 13);
	if(!font_italic)
		{
			char str[256];
		    sprintf(str,"TTF_OpenFont: %s\n", TTF_GetError());
		    log_message(str);
		    return -1;
		}

	//load the bold font
	font_italic_bold=TTF_OpenFont("./fonts/LiberationSans-BoldItalic.ttf", 13);
	if(!font_italic_bold)
		{
			char str[256];
		    sprintf(str,"TTF_OpenFont: %s\n", TTF_GetError());
		    log_message(str);
		    return -1;
		}

	return 1;
}

